from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_type import CheckType
from ..types import UNSET, Unset

T = TypeVar("T", bound="NotificationFilterSpec")


@_attrs_define
class NotificationFilterSpec:
    r"""
    Attributes:
        connection (Union[Unset, str]): Connection name. Supports search patterns in the format: 'source\*', '\*_prod',
            'prefix\*suffix'.
        schema (Union[Unset, str]): Schema name. This field accepts search patterns in the format: 'schema_name_\*',
            '\*_schema', 'prefix\*suffix'.
        table (Union[Unset, str]): Table name. This field accepts search patterns in the format: 'table_name_\*',
            '\*table', 'prefix\*suffix'.
        table_priority (Union[Unset, int]): Table priority.
        data_group_name (Union[Unset, str]): Data group name. This field accepts search patterns in the format:
            'group_name_\*', '\*group', 'prefix\*suffix'.
        quality_dimension (Union[Unset, str]): Quality dimension.
        check_category (Union[Unset, str]): The target check category, for example: *nulls*, *volume*, *anomaly*.
        check_type (Union[Unset, CheckType]):
        check_name (Union[Unset, str]): The target check name to run only this named check. Uses the short check name
            which is the name of the deepest folder in the *checks* folder. This field supports search patterns such as:
            'profiling_\*', '\*_count', 'profiling_\*_percent'.
        highest_severity (Union[Unset, int]): Highest severity.
    """

    connection: Union[Unset, str] = UNSET
    schema: Union[Unset, str] = UNSET
    table: Union[Unset, str] = UNSET
    table_priority: Union[Unset, int] = UNSET
    data_group_name: Union[Unset, str] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    check_category: Union[Unset, str] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    check_name: Union[Unset, str] = UNSET
    highest_severity: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection = self.connection
        schema = self.schema
        table = self.table
        table_priority = self.table_priority
        data_group_name = self.data_group_name
        quality_dimension = self.quality_dimension
        check_category = self.check_category
        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        check_name = self.check_name
        highest_severity = self.highest_severity

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection is not UNSET:
            field_dict["connection"] = connection
        if schema is not UNSET:
            field_dict["schema"] = schema
        if table is not UNSET:
            field_dict["table"] = table
        if table_priority is not UNSET:
            field_dict["tablePriority"] = table_priority
        if data_group_name is not UNSET:
            field_dict["dataGroupName"] = data_group_name
        if quality_dimension is not UNSET:
            field_dict["qualityDimension"] = quality_dimension
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if highest_severity is not UNSET:
            field_dict["highestSeverity"] = highest_severity

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        connection = d.pop("connection", UNSET)

        schema = d.pop("schema", UNSET)

        table = d.pop("table", UNSET)

        table_priority = d.pop("tablePriority", UNSET)

        data_group_name = d.pop("dataGroupName", UNSET)

        quality_dimension = d.pop("qualityDimension", UNSET)

        check_category = d.pop("checkCategory", UNSET)

        _check_type = d.pop("checkType", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        check_name = d.pop("checkName", UNSET)

        highest_severity = d.pop("highestSeverity", UNSET)

        notification_filter_spec = cls(
            connection=connection,
            schema=schema,
            table=table,
            table_priority=table_priority,
            data_group_name=data_group_name,
            quality_dimension=quality_dimension,
            check_category=check_category,
            check_type=check_type,
            check_name=check_name,
            highest_severity=highest_severity,
        )

        notification_filter_spec.additional_properties = d
        return notification_filter_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_accepted_values_daily_partitioned_checks_spec import (
        ColumnAcceptedValuesDailyPartitionedChecksSpec,
    )
    from ..models.column_anomaly_daily_partitioned_checks_spec import (
        ColumnAnomalyDailyPartitionedChecksSpec,
    )
    from ..models.column_bool_daily_partitioned_checks_spec import (
        ColumnBoolDailyPartitionedChecksSpec,
    )
    from ..models.column_conversions_daily_partitioned_checks_spec import (
        ColumnConversionsDailyPartitionedChecksSpec,
    )
    from ..models.column_custom_sql_daily_partitioned_checks_spec import (
        ColumnCustomSqlDailyPartitionedChecksSpec,
    )
    from ..models.column_daily_partitioned_check_categories_spec_comparisons import (
        ColumnDailyPartitionedCheckCategoriesSpecComparisons,
    )
    from ..models.column_daily_partitioned_check_categories_spec_custom import (
        ColumnDailyPartitionedCheckCategoriesSpecCustom,
    )
    from ..models.column_datatype_daily_partitioned_checks_spec import (
        ColumnDatatypeDailyPartitionedChecksSpec,
    )
    from ..models.column_datetime_daily_partitioned_checks_spec import (
        ColumnDatetimeDailyPartitionedChecksSpec,
    )
    from ..models.column_integrity_daily_partitioned_checks_spec import (
        ColumnIntegrityDailyPartitionedChecksSpec,
    )
    from ..models.column_nulls_daily_partitioned_checks_spec import (
        ColumnNullsDailyPartitionedChecksSpec,
    )
    from ..models.column_numeric_daily_partitioned_checks_spec import (
        ColumnNumericDailyPartitionedChecksSpec,
    )
    from ..models.column_patterns_daily_partitioned_checks_spec import (
        ColumnPatternsDailyPartitionedChecksSpec,
    )
    from ..models.column_pii_daily_partitioned_checks_spec import (
        ColumnPiiDailyPartitionedChecksSpec,
    )
    from ..models.column_text_daily_partitioned_checks_spec import (
        ColumnTextDailyPartitionedChecksSpec,
    )
    from ..models.column_uniqueness_daily_partitioned_checks_spec import (
        ColumnUniquenessDailyPartitionedChecksSpec,
    )
    from ..models.column_whitespace_daily_partitioned_checks_spec import (
        ColumnWhitespaceDailyPartitionedChecksSpec,
    )


T = TypeVar("T", bound="ColumnDailyPartitionedCheckCategoriesSpec")


@_attrs_define
class ColumnDailyPartitionedCheckCategoriesSpec:
    """
    Attributes:
        custom (Union[Unset, ColumnDailyPartitionedCheckCategoriesSpecCustom]): Dictionary of custom checks. The keys
            are check names within this category.
        nulls (Union[Unset, ColumnNullsDailyPartitionedChecksSpec]):
        uniqueness (Union[Unset, ColumnUniquenessDailyPartitionedChecksSpec]):
        accepted_values (Union[Unset, ColumnAcceptedValuesDailyPartitionedChecksSpec]):
        text (Union[Unset, ColumnTextDailyPartitionedChecksSpec]):
        whitespace (Union[Unset, ColumnWhitespaceDailyPartitionedChecksSpec]):
        conversions (Union[Unset, ColumnConversionsDailyPartitionedChecksSpec]):
        patterns (Union[Unset, ColumnPatternsDailyPartitionedChecksSpec]):
        pii (Union[Unset, ColumnPiiDailyPartitionedChecksSpec]):
        numeric (Union[Unset, ColumnNumericDailyPartitionedChecksSpec]):
        anomaly (Union[Unset, ColumnAnomalyDailyPartitionedChecksSpec]):
        datetime_ (Union[Unset, ColumnDatetimeDailyPartitionedChecksSpec]):
        bool_ (Union[Unset, ColumnBoolDailyPartitionedChecksSpec]):
        integrity (Union[Unset, ColumnIntegrityDailyPartitionedChecksSpec]):
        custom_sql (Union[Unset, ColumnCustomSqlDailyPartitionedChecksSpec]):
        datatype (Union[Unset, ColumnDatatypeDailyPartitionedChecksSpec]):
        comparisons (Union[Unset, ColumnDailyPartitionedCheckCategoriesSpecComparisons]): Dictionary of configuration of
            checks for table comparisons at a column level. The key that identifies each comparison must match the name of a
            data comparison that is configured on the parent table.
    """

    custom: Union[Unset, "ColumnDailyPartitionedCheckCategoriesSpecCustom"] = UNSET
    nulls: Union[Unset, "ColumnNullsDailyPartitionedChecksSpec"] = UNSET
    uniqueness: Union[Unset, "ColumnUniquenessDailyPartitionedChecksSpec"] = UNSET
    accepted_values: Union[Unset, "ColumnAcceptedValuesDailyPartitionedChecksSpec"] = (
        UNSET
    )
    text: Union[Unset, "ColumnTextDailyPartitionedChecksSpec"] = UNSET
    whitespace: Union[Unset, "ColumnWhitespaceDailyPartitionedChecksSpec"] = UNSET
    conversions: Union[Unset, "ColumnConversionsDailyPartitionedChecksSpec"] = UNSET
    patterns: Union[Unset, "ColumnPatternsDailyPartitionedChecksSpec"] = UNSET
    pii: Union[Unset, "ColumnPiiDailyPartitionedChecksSpec"] = UNSET
    numeric: Union[Unset, "ColumnNumericDailyPartitionedChecksSpec"] = UNSET
    anomaly: Union[Unset, "ColumnAnomalyDailyPartitionedChecksSpec"] = UNSET
    datetime_: Union[Unset, "ColumnDatetimeDailyPartitionedChecksSpec"] = UNSET
    bool_: Union[Unset, "ColumnBoolDailyPartitionedChecksSpec"] = UNSET
    integrity: Union[Unset, "ColumnIntegrityDailyPartitionedChecksSpec"] = UNSET
    custom_sql: Union[Unset, "ColumnCustomSqlDailyPartitionedChecksSpec"] = UNSET
    datatype: Union[Unset, "ColumnDatatypeDailyPartitionedChecksSpec"] = UNSET
    comparisons: Union[
        Unset, "ColumnDailyPartitionedCheckCategoriesSpecComparisons"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom, Unset):
            custom = self.custom.to_dict()

        nulls: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.nulls, Unset):
            nulls = self.nulls.to_dict()

        uniqueness: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.uniqueness, Unset):
            uniqueness = self.uniqueness.to_dict()

        accepted_values: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.accepted_values, Unset):
            accepted_values = self.accepted_values.to_dict()

        text: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.text, Unset):
            text = self.text.to_dict()

        whitespace: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.whitespace, Unset):
            whitespace = self.whitespace.to_dict()

        conversions: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.conversions, Unset):
            conversions = self.conversions.to_dict()

        patterns: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.patterns, Unset):
            patterns = self.patterns.to_dict()

        pii: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.pii, Unset):
            pii = self.pii.to_dict()

        numeric: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.numeric, Unset):
            numeric = self.numeric.to_dict()

        anomaly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.anomaly, Unset):
            anomaly = self.anomaly.to_dict()

        datetime_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.datetime_, Unset):
            datetime_ = self.datetime_.to_dict()

        bool_: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.bool_, Unset):
            bool_ = self.bool_.to_dict()

        integrity: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.integrity, Unset):
            integrity = self.integrity.to_dict()

        custom_sql: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_sql, Unset):
            custom_sql = self.custom_sql.to_dict()

        datatype: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.datatype, Unset):
            datatype = self.datatype.to_dict()

        comparisons: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.comparisons, Unset):
            comparisons = self.comparisons.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom is not UNSET:
            field_dict["custom"] = custom
        if nulls is not UNSET:
            field_dict["nulls"] = nulls
        if uniqueness is not UNSET:
            field_dict["uniqueness"] = uniqueness
        if accepted_values is not UNSET:
            field_dict["accepted_values"] = accepted_values
        if text is not UNSET:
            field_dict["text"] = text
        if whitespace is not UNSET:
            field_dict["whitespace"] = whitespace
        if conversions is not UNSET:
            field_dict["conversions"] = conversions
        if patterns is not UNSET:
            field_dict["patterns"] = patterns
        if pii is not UNSET:
            field_dict["pii"] = pii
        if numeric is not UNSET:
            field_dict["numeric"] = numeric
        if anomaly is not UNSET:
            field_dict["anomaly"] = anomaly
        if datetime_ is not UNSET:
            field_dict["datetime"] = datetime_
        if bool_ is not UNSET:
            field_dict["bool"] = bool_
        if integrity is not UNSET:
            field_dict["integrity"] = integrity
        if custom_sql is not UNSET:
            field_dict["custom_sql"] = custom_sql
        if datatype is not UNSET:
            field_dict["datatype"] = datatype
        if comparisons is not UNSET:
            field_dict["comparisons"] = comparisons

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_accepted_values_daily_partitioned_checks_spec import (
            ColumnAcceptedValuesDailyPartitionedChecksSpec,
        )
        from ..models.column_anomaly_daily_partitioned_checks_spec import (
            ColumnAnomalyDailyPartitionedChecksSpec,
        )
        from ..models.column_bool_daily_partitioned_checks_spec import (
            ColumnBoolDailyPartitionedChecksSpec,
        )
        from ..models.column_conversions_daily_partitioned_checks_spec import (
            ColumnConversionsDailyPartitionedChecksSpec,
        )
        from ..models.column_custom_sql_daily_partitioned_checks_spec import (
            ColumnCustomSqlDailyPartitionedChecksSpec,
        )
        from ..models.column_daily_partitioned_check_categories_spec_comparisons import (
            ColumnDailyPartitionedCheckCategoriesSpecComparisons,
        )
        from ..models.column_daily_partitioned_check_categories_spec_custom import (
            ColumnDailyPartitionedCheckCategoriesSpecCustom,
        )
        from ..models.column_datatype_daily_partitioned_checks_spec import (
            ColumnDatatypeDailyPartitionedChecksSpec,
        )
        from ..models.column_datetime_daily_partitioned_checks_spec import (
            ColumnDatetimeDailyPartitionedChecksSpec,
        )
        from ..models.column_integrity_daily_partitioned_checks_spec import (
            ColumnIntegrityDailyPartitionedChecksSpec,
        )
        from ..models.column_nulls_daily_partitioned_checks_spec import (
            ColumnNullsDailyPartitionedChecksSpec,
        )
        from ..models.column_numeric_daily_partitioned_checks_spec import (
            ColumnNumericDailyPartitionedChecksSpec,
        )
        from ..models.column_patterns_daily_partitioned_checks_spec import (
            ColumnPatternsDailyPartitionedChecksSpec,
        )
        from ..models.column_pii_daily_partitioned_checks_spec import (
            ColumnPiiDailyPartitionedChecksSpec,
        )
        from ..models.column_text_daily_partitioned_checks_spec import (
            ColumnTextDailyPartitionedChecksSpec,
        )
        from ..models.column_uniqueness_daily_partitioned_checks_spec import (
            ColumnUniquenessDailyPartitionedChecksSpec,
        )
        from ..models.column_whitespace_daily_partitioned_checks_spec import (
            ColumnWhitespaceDailyPartitionedChecksSpec,
        )

        d = src_dict.copy()
        _custom = d.pop("custom", UNSET)
        custom: Union[Unset, ColumnDailyPartitionedCheckCategoriesSpecCustom]
        if isinstance(_custom, Unset):
            custom = UNSET
        else:
            custom = ColumnDailyPartitionedCheckCategoriesSpecCustom.from_dict(_custom)

        _nulls = d.pop("nulls", UNSET)
        nulls: Union[Unset, ColumnNullsDailyPartitionedChecksSpec]
        if isinstance(_nulls, Unset):
            nulls = UNSET
        else:
            nulls = ColumnNullsDailyPartitionedChecksSpec.from_dict(_nulls)

        _uniqueness = d.pop("uniqueness", UNSET)
        uniqueness: Union[Unset, ColumnUniquenessDailyPartitionedChecksSpec]
        if isinstance(_uniqueness, Unset):
            uniqueness = UNSET
        else:
            uniqueness = ColumnUniquenessDailyPartitionedChecksSpec.from_dict(
                _uniqueness
            )

        _accepted_values = d.pop("accepted_values", UNSET)
        accepted_values: Union[Unset, ColumnAcceptedValuesDailyPartitionedChecksSpec]
        if isinstance(_accepted_values, Unset):
            accepted_values = UNSET
        else:
            accepted_values = ColumnAcceptedValuesDailyPartitionedChecksSpec.from_dict(
                _accepted_values
            )

        _text = d.pop("text", UNSET)
        text: Union[Unset, ColumnTextDailyPartitionedChecksSpec]
        if isinstance(_text, Unset):
            text = UNSET
        else:
            text = ColumnTextDailyPartitionedChecksSpec.from_dict(_text)

        _whitespace = d.pop("whitespace", UNSET)
        whitespace: Union[Unset, ColumnWhitespaceDailyPartitionedChecksSpec]
        if isinstance(_whitespace, Unset):
            whitespace = UNSET
        else:
            whitespace = ColumnWhitespaceDailyPartitionedChecksSpec.from_dict(
                _whitespace
            )

        _conversions = d.pop("conversions", UNSET)
        conversions: Union[Unset, ColumnConversionsDailyPartitionedChecksSpec]
        if isinstance(_conversions, Unset):
            conversions = UNSET
        else:
            conversions = ColumnConversionsDailyPartitionedChecksSpec.from_dict(
                _conversions
            )

        _patterns = d.pop("patterns", UNSET)
        patterns: Union[Unset, ColumnPatternsDailyPartitionedChecksSpec]
        if isinstance(_patterns, Unset):
            patterns = UNSET
        else:
            patterns = ColumnPatternsDailyPartitionedChecksSpec.from_dict(_patterns)

        _pii = d.pop("pii", UNSET)
        pii: Union[Unset, ColumnPiiDailyPartitionedChecksSpec]
        if isinstance(_pii, Unset):
            pii = UNSET
        else:
            pii = ColumnPiiDailyPartitionedChecksSpec.from_dict(_pii)

        _numeric = d.pop("numeric", UNSET)
        numeric: Union[Unset, ColumnNumericDailyPartitionedChecksSpec]
        if isinstance(_numeric, Unset):
            numeric = UNSET
        else:
            numeric = ColumnNumericDailyPartitionedChecksSpec.from_dict(_numeric)

        _anomaly = d.pop("anomaly", UNSET)
        anomaly: Union[Unset, ColumnAnomalyDailyPartitionedChecksSpec]
        if isinstance(_anomaly, Unset):
            anomaly = UNSET
        else:
            anomaly = ColumnAnomalyDailyPartitionedChecksSpec.from_dict(_anomaly)

        _datetime_ = d.pop("datetime", UNSET)
        datetime_: Union[Unset, ColumnDatetimeDailyPartitionedChecksSpec]
        if isinstance(_datetime_, Unset):
            datetime_ = UNSET
        else:
            datetime_ = ColumnDatetimeDailyPartitionedChecksSpec.from_dict(_datetime_)

        _bool_ = d.pop("bool", UNSET)
        bool_: Union[Unset, ColumnBoolDailyPartitionedChecksSpec]
        if isinstance(_bool_, Unset):
            bool_ = UNSET
        else:
            bool_ = ColumnBoolDailyPartitionedChecksSpec.from_dict(_bool_)

        _integrity = d.pop("integrity", UNSET)
        integrity: Union[Unset, ColumnIntegrityDailyPartitionedChecksSpec]
        if isinstance(_integrity, Unset):
            integrity = UNSET
        else:
            integrity = ColumnIntegrityDailyPartitionedChecksSpec.from_dict(_integrity)

        _custom_sql = d.pop("custom_sql", UNSET)
        custom_sql: Union[Unset, ColumnCustomSqlDailyPartitionedChecksSpec]
        if isinstance(_custom_sql, Unset):
            custom_sql = UNSET
        else:
            custom_sql = ColumnCustomSqlDailyPartitionedChecksSpec.from_dict(
                _custom_sql
            )

        _datatype = d.pop("datatype", UNSET)
        datatype: Union[Unset, ColumnDatatypeDailyPartitionedChecksSpec]
        if isinstance(_datatype, Unset):
            datatype = UNSET
        else:
            datatype = ColumnDatatypeDailyPartitionedChecksSpec.from_dict(_datatype)

        _comparisons = d.pop("comparisons", UNSET)
        comparisons: Union[Unset, ColumnDailyPartitionedCheckCategoriesSpecComparisons]
        if isinstance(_comparisons, Unset):
            comparisons = UNSET
        else:
            comparisons = (
                ColumnDailyPartitionedCheckCategoriesSpecComparisons.from_dict(
                    _comparisons
                )
            )

        column_daily_partitioned_check_categories_spec = cls(
            custom=custom,
            nulls=nulls,
            uniqueness=uniqueness,
            accepted_values=accepted_values,
            text=text,
            whitespace=whitespace,
            conversions=conversions,
            patterns=patterns,
            pii=pii,
            numeric=numeric,
            anomaly=anomaly,
            datetime_=datetime_,
            bool_=bool_,
            integrity=integrity,
            custom_sql=custom_sql,
            datatype=datatype,
            comparisons=comparisons,
        )

        column_daily_partitioned_check_categories_spec.additional_properties = d
        return column_daily_partitioned_check_categories_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="AnomalyStationaryPercentValuesRuleFatal01PctParametersSpec")


@_attrs_define
class AnomalyStationaryPercentValuesRuleFatal01PctParametersSpec:
    """
    Attributes:
        anomaly_percent (Union[Unset, float]): The probability (in percent) that the current percentage value is an
            anomaly because the value is outside the regular range of captured percentage measures. The default time window
            of 90 time periods (days, etc.) is used, but at least 30 readouts must exist to run the calculation.
        use_ai (Union[Unset, bool]): Use an AI model to predict anomalies. WARNING: anomaly detection by AI models is
            not supported in an open-source distribution of DQOps. Please contact DQOps support to upgrade your instance to
            a closed-source DQOps distribution.
    """

    anomaly_percent: Union[Unset, float] = UNSET
    use_ai: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        anomaly_percent = self.anomaly_percent
        use_ai = self.use_ai

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if anomaly_percent is not UNSET:
            field_dict["anomaly_percent"] = anomaly_percent
        if use_ai is not UNSET:
            field_dict["use_ai"] = use_ai

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        anomaly_percent = d.pop("anomaly_percent", UNSET)

        use_ai = d.pop("use_ai", UNSET)

        anomaly_stationary_percent_values_rule_fatal_01_pct_parameters_spec = cls(
            anomaly_percent=anomaly_percent,
            use_ai=use_ai,
        )

        anomaly_stationary_percent_values_rule_fatal_01_pct_parameters_spec.additional_properties = (
            d
        )
        return anomaly_stationary_percent_values_rule_fatal_01_pct_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...types import Response


def _get_kwargs() -> Dict[str, Any]:

    pass

    return {
        "method": "get",
        "url": "api/environment/issueapikey",
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[str]:
    if response.status_code == HTTPStatus.OK:
        response_200 = cast(str, response.json())
        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[str]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[str]:
    r"""issueApiKey

     Issues a local API Key for the calling user. This API Key can be used to authenticate using the
    DQOps REST API client. This API Key should be passed in the \"Authorization\" HTTP header in the
    format \"Authorization: Bearer <api_key>\".

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[str]
    """

    kwargs = _get_kwargs()

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
) -> Optional[str]:
    r"""issueApiKey

     Issues a local API Key for the calling user. This API Key can be used to authenticate using the
    DQOps REST API client. This API Key should be passed in the \"Authorization\" HTTP header in the
    format \"Authorization: Bearer <api_key>\".

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        str
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[str]:
    r"""issueApiKey

     Issues a local API Key for the calling user. This API Key can be used to authenticate using the
    DQOps REST API client. This API Key should be passed in the \"Authorization\" HTTP header in the
    format \"Authorization: Bearer <api_key>\".

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[str]
    """

    kwargs = _get_kwargs()

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
) -> Optional[str]:
    r"""issueApiKey

     Issues a local API Key for the calling user. This API Key can be used to authenticate using the
    DQOps REST API client. This API Key should be passed in the \"Authorization\" HTTP header in the
    format \"Authorization: Bearer <api_key>\".

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        str
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_target import CheckTarget
from ..models.check_time_scale import CheckTimeScale
from ..models.check_type import CheckType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.hierarchy_id_model import HierarchyIdModel


T = TypeVar("T", bound="CheckSearchFilters")


@_attrs_define
class CheckSearchFilters:
    r"""Target data quality checks filter, identifies which checks on which tables and columns should be executed.

    Attributes:
        connection (Union[Unset, str]): The connection (data source) name. Supports search patterns in the format:
            'source\*', '\*_prod', 'prefix\*suffix'.
        full_table_name (Union[Unset, str]): The schema and table name. It is provided as *<schema_name>.<table_name>*,
            for example *public.fact_sales*. The schema and table name accept patterns both in the schema name and table
            name parts. Sample patterns are: 'schema_name.tab_prefix_\*', 'schema_name.*', '*.*', 'schema_name.\*_customer',
            'schema_name.tab_\*_suffix'.
        enabled (Union[Unset, bool]): A boolean flag to target enabled tables, columns or checks. When the value of this
            field is not set, the default value of this field is *true*, targeting only tables, columns and checks that are
            not implicitly disabled.
        tags (Union[Unset, List[str]]): An array of tags assigned to the table. All tags must be present on a table to
            match. The tags can use patterns:  'prefix\*', '\*suffix', 'prefix\*suffix'. The tags are assigned to the table
            on the data grouping screen when any of the data grouping hierarchy level is assigned a static value, which is a
            tag.
        labels (Union[Unset, List[str]]): An array of labels assigned to the table. All labels must be present on a
            table to match. The labels can use patterns:  'prefix\*', '\*suffix', 'prefix\*suffix'. The labels are assigned
            on the labels screen and stored in the *labels* node in the *.dqotable.yaml* file.
        max_results (Union[Unset, int]): Optional limit for the maximum number of results to return.
        column (Union[Unset, str]): The column name. This field accepts search patterns in the format: 'fk_\*', '\*_id',
            'prefix\*suffix'.
        column_data_type (Union[Unset, str]): The column data type that was imported from the data source and is stored
            in the [columns -> column_name -> type_snapshot ->
            column_type](/docs/reference/yaml/TableYaml/#columntypesnapshotspec) field in the *.dqotable.yaml* file.
        column_nullable (Union[Unset, bool]): Optional filter to find only nullable (when the value is *true*) or not
            nullable (when the value is *false*) columns, based on the value of the [columns -> column_name -> type_snapshot
            -> nullable](/docs/reference/yaml/TableYaml/#columntypesnapshotspec) field in the *.dqotable.yaml* file.
        check_target (Union[Unset, CheckTarget]):
        check_type (Union[Unset, CheckType]):
        time_scale (Union[Unset, CheckTimeScale]):
        check_category (Union[Unset, str]): The target check category, for example: *nulls*, *volume*, *anomaly*.
        quality_dimension (Union[Unset, str]): The target data quality dimension, for example: *Completeness*,
            *Accuracy*, *Consistency*, *Timeliness*, *Availability*.
        table_comparison_name (Union[Unset, str]): The name of a configured table comparison. When the table comparison
            is provided, DQOps will only perform table comparison checks that compare data between tables.
        check_name (Union[Unset, str]): The target check name to run only this named check. Uses the short check name
            which is the name of the deepest folder in the *checks* folder. This field supports search patterns such as:
            'profiling_\*', '\*_count', 'profiling_\*_percent'.
        sensor_name (Union[Unset, str]): The target sensor name to run only data quality checks that are using this
            sensor. Uses the full sensor name which is the full folder path within the *sensors* folder. This field supports
            search patterns such as: 'table/volume/row_\*', '\*_count', 'table/volume/prefix_\*_suffix'.
        check_hierarchy_ids_models (Union[Unset, List['HierarchyIdModel']]):
    """

    connection: Union[Unset, str] = UNSET
    full_table_name: Union[Unset, str] = UNSET
    enabled: Union[Unset, bool] = UNSET
    tags: Union[Unset, List[str]] = UNSET
    labels: Union[Unset, List[str]] = UNSET
    max_results: Union[Unset, int] = UNSET
    column: Union[Unset, str] = UNSET
    column_data_type: Union[Unset, str] = UNSET
    column_nullable: Union[Unset, bool] = UNSET
    check_target: Union[Unset, CheckTarget] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    time_scale: Union[Unset, CheckTimeScale] = UNSET
    check_category: Union[Unset, str] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    table_comparison_name: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    check_hierarchy_ids_models: Union[Unset, List["HierarchyIdModel"]] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        connection = self.connection
        full_table_name = self.full_table_name
        enabled = self.enabled
        tags: Union[Unset, List[str]] = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags

        labels: Union[Unset, List[str]] = UNSET
        if not isinstance(self.labels, Unset):
            labels = self.labels

        max_results = self.max_results
        column = self.column
        column_data_type = self.column_data_type
        column_nullable = self.column_nullable
        check_target: Union[Unset, str] = UNSET
        if not isinstance(self.check_target, Unset):
            check_target = self.check_target.value

        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        time_scale: Union[Unset, str] = UNSET
        if not isinstance(self.time_scale, Unset):
            time_scale = self.time_scale.value

        check_category = self.check_category
        quality_dimension = self.quality_dimension
        table_comparison_name = self.table_comparison_name
        check_name = self.check_name
        sensor_name = self.sensor_name
        check_hierarchy_ids_models: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.check_hierarchy_ids_models, Unset):
            check_hierarchy_ids_models = []
            for check_hierarchy_ids_models_item_data in self.check_hierarchy_ids_models:
                check_hierarchy_ids_models_item = (
                    check_hierarchy_ids_models_item_data.to_dict()
                )

                check_hierarchy_ids_models.append(check_hierarchy_ids_models_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if connection is not UNSET:
            field_dict["connection"] = connection
        if full_table_name is not UNSET:
            field_dict["fullTableName"] = full_table_name
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if tags is not UNSET:
            field_dict["tags"] = tags
        if labels is not UNSET:
            field_dict["labels"] = labels
        if max_results is not UNSET:
            field_dict["maxResults"] = max_results
        if column is not UNSET:
            field_dict["column"] = column
        if column_data_type is not UNSET:
            field_dict["columnDataType"] = column_data_type
        if column_nullable is not UNSET:
            field_dict["columnNullable"] = column_nullable
        if check_target is not UNSET:
            field_dict["checkTarget"] = check_target
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if time_scale is not UNSET:
            field_dict["timeScale"] = time_scale
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if quality_dimension is not UNSET:
            field_dict["qualityDimension"] = quality_dimension
        if table_comparison_name is not UNSET:
            field_dict["tableComparisonName"] = table_comparison_name
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if sensor_name is not UNSET:
            field_dict["sensorName"] = sensor_name
        if check_hierarchy_ids_models is not UNSET:
            field_dict["checkHierarchyIdsModels"] = check_hierarchy_ids_models

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.hierarchy_id_model import HierarchyIdModel

        d = src_dict.copy()
        connection = d.pop("connection", UNSET)

        full_table_name = d.pop("fullTableName", UNSET)

        enabled = d.pop("enabled", UNSET)

        tags = cast(List[str], d.pop("tags", UNSET))

        labels = cast(List[str], d.pop("labels", UNSET))

        max_results = d.pop("maxResults", UNSET)

        column = d.pop("column", UNSET)

        column_data_type = d.pop("columnDataType", UNSET)

        column_nullable = d.pop("columnNullable", UNSET)

        _check_target = d.pop("checkTarget", UNSET)
        check_target: Union[Unset, CheckTarget]
        if isinstance(_check_target, Unset):
            check_target = UNSET
        else:
            check_target = CheckTarget(_check_target)

        _check_type = d.pop("checkType", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        _time_scale = d.pop("timeScale", UNSET)
        time_scale: Union[Unset, CheckTimeScale]
        if isinstance(_time_scale, Unset):
            time_scale = UNSET
        else:
            time_scale = CheckTimeScale(_time_scale)

        check_category = d.pop("checkCategory", UNSET)

        quality_dimension = d.pop("qualityDimension", UNSET)

        table_comparison_name = d.pop("tableComparisonName", UNSET)

        check_name = d.pop("checkName", UNSET)

        sensor_name = d.pop("sensorName", UNSET)

        check_hierarchy_ids_models = []
        _check_hierarchy_ids_models = d.pop("checkHierarchyIdsModels", UNSET)
        for check_hierarchy_ids_models_item_data in _check_hierarchy_ids_models or []:
            check_hierarchy_ids_models_item = HierarchyIdModel.from_dict(
                check_hierarchy_ids_models_item_data
            )

            check_hierarchy_ids_models.append(check_hierarchy_ids_models_item)

        check_search_filters = cls(
            connection=connection,
            full_table_name=full_table_name,
            enabled=enabled,
            tags=tags,
            labels=labels,
            max_results=max_results,
            column=column,
            column_data_type=column_data_type,
            column_nullable=column_nullable,
            check_target=check_target,
            check_type=check_type,
            time_scale=time_scale,
            check_category=check_category,
            quality_dimension=quality_dimension,
            table_comparison_name=table_comparison_name,
            check_name=check_name,
            sensor_name=sensor_name,
            check_hierarchy_ids_models=check_hierarchy_ids_models,
        )

        check_search_filters.additional_properties = d
        return check_search_filters

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class IncidentSortOrder(str, Enum):
    CHECKNAME = "checkName"
    DATAGROUP = "dataGroup"
    FAILEDCHECKSCOUNT = "failedChecksCount"
    FIRSTSEEN = "firstSeen"
    HIGHESTSEVERITY = "highestSeverity"
    LASTSEEN = "lastSeen"
    QUALITYDIMENSION = "qualityDimension"
    TABLE = "table"
    TABLEPRIORITY = "tablePriority"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class RunChecksTarget(str, Enum):
    ONLY_RULES = "only_rules"
    ONLY_SENSORS = "only_sensors"
    SENSORS_AND_RULES = "sensors_and_rules"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.data_grouping_dimension_source import DataGroupingDimensionSource
from ..types import UNSET, Unset

T = TypeVar("T", bound="DataGroupingDimensionSpec")


@_attrs_define
class DataGroupingDimensionSpec:
    """
    Attributes:
        source (Union[Unset, DataGroupingDimensionSource]):
        tag (Union[Unset, str]): The value assigned to the data quality grouping dimension when the source is 'tag'.
            Assign a hard-coded (static) value to the data grouping dimension (tag) when there are multiple similar tables
            storing the same data for different areas (countries, etc.). This can be the name of the country if the table or
            partition stores information for that country.
        column (Union[Unset, str]): Column name that contains a dynamic data grouping dimension value (for dynamic data-
            driven data groupings). Sensor queries will be extended with a GROUP BY {data group level colum name}, sensors
            (and alerts) will be calculated for each unique value of the specified column. Also a separate time series will
            be tracked for each value.
        name (Union[Unset, str]): Data grouping dimension name.
    """

    source: Union[Unset, DataGroupingDimensionSource] = UNSET
    tag: Union[Unset, str] = UNSET
    column: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        source: Union[Unset, str] = UNSET
        if not isinstance(self.source, Unset):
            source = self.source.value

        tag = self.tag
        column = self.column
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if source is not UNSET:
            field_dict["source"] = source
        if tag is not UNSET:
            field_dict["tag"] = tag
        if column is not UNSET:
            field_dict["column"] = column
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _source = d.pop("source", UNSET)
        source: Union[Unset, DataGroupingDimensionSource]
        if isinstance(_source, Unset):
            source = UNSET
        else:
            source = DataGroupingDimensionSource(_source)

        tag = d.pop("tag", UNSET)

        column = d.pop("column", UNSET)

        name = d.pop("name", UNSET)

        data_grouping_dimension_spec = cls(
            source=source,
            tag=tag,
            column=column,
            name=name,
        )

        data_grouping_dimension_spec.additional_properties = d
        return data_grouping_dimension_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...types import Response


def _get_kwargs() -> Dict[str, Any]:

    pass

    return {
        "method": "put",
        "url": "api/mypassword",
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Any]:
    if response.status_code == HTTPStatus.CREATED:
        return None
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Any]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[Any]:
    """changeCallerPassword

     Changes the password of the calling user. When the user is identified by the DQOps local API key, it
    is the user whose email is stored in the DQOps API Key.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs()

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[Any]:
    """changeCallerPassword

     Changes the password of the calling user. When the user is identified by the DQOps local API key, it
    is the user whose email is stored in the DQOps API Key.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs()

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.check_time_scale import CheckTimeScale
from ..models.check_type import CheckType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.table_comparison_grouping_columns_pair_spec import (
        TableComparisonGroupingColumnsPairSpec,
    )


T = TypeVar("T", bound="TableComparisonConfigurationSpec")


@_attrs_define
class TableComparisonConfigurationSpec:
    """
    Attributes:
        reference_table_connection_name (Union[Unset, str]): The name of the connection in DQOp where the reference
            table (the source of truth) is configured. When the connection name is not provided, DQOps will find the
            reference table on the connection of the parent table.
        reference_table_schema_name (Union[Unset, str]): The name of the schema where the reference table is imported
            into DQOps. The reference table's metadata must be imported into DQOps.
        reference_table_name (Union[Unset, str]): The name of the reference table that is imported into DQOps. The
            reference table's metadata must be imported into DQOps.
        compared_table_filter (Union[Unset, str]): Optional custom SQL filter expression that is added to the SQL query
            that retrieves the data from the compared table. This expression must be a SQL expression that will be added to
            the WHERE clause when querying the compared table.
        reference_table_filter (Union[Unset, str]): Optional custom SQL filter expression that is added to the SQL query
            that retrieves the data from the reference table (the source of truth). This expression must be a SQL expression
            that will be added to the WHERE clause when querying the reference table.
        check_type (Union[Unset, CheckType]):
        time_scale (Union[Unset, CheckTimeScale]):
        grouping_columns (Union[Unset, List['TableComparisonGroupingColumnsPairSpec']]): List of column pairs from both
            the compared table and the reference table that are used in a GROUP BY clause  for grouping both the compared
            table and the reference table (the source of truth). The columns are used in the next of the table comparison to
            join the results of data groups (row counts, sums of columns) between the compared table and the reference table
            to compare the differences.
    """

    reference_table_connection_name: Union[Unset, str] = UNSET
    reference_table_schema_name: Union[Unset, str] = UNSET
    reference_table_name: Union[Unset, str] = UNSET
    compared_table_filter: Union[Unset, str] = UNSET
    reference_table_filter: Union[Unset, str] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    time_scale: Union[Unset, CheckTimeScale] = UNSET
    grouping_columns: Union[Unset, List["TableComparisonGroupingColumnsPairSpec"]] = (
        UNSET
    )
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        reference_table_connection_name = self.reference_table_connection_name
        reference_table_schema_name = self.reference_table_schema_name
        reference_table_name = self.reference_table_name
        compared_table_filter = self.compared_table_filter
        reference_table_filter = self.reference_table_filter
        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        time_scale: Union[Unset, str] = UNSET
        if not isinstance(self.time_scale, Unset):
            time_scale = self.time_scale.value

        grouping_columns: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.grouping_columns, Unset):
            grouping_columns = []
            for grouping_columns_item_data in self.grouping_columns:
                grouping_columns_item = grouping_columns_item_data.to_dict()

                grouping_columns.append(grouping_columns_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if reference_table_connection_name is not UNSET:
            field_dict["reference_table_connection_name"] = (
                reference_table_connection_name
            )
        if reference_table_schema_name is not UNSET:
            field_dict["reference_table_schema_name"] = reference_table_schema_name
        if reference_table_name is not UNSET:
            field_dict["reference_table_name"] = reference_table_name
        if compared_table_filter is not UNSET:
            field_dict["compared_table_filter"] = compared_table_filter
        if reference_table_filter is not UNSET:
            field_dict["reference_table_filter"] = reference_table_filter
        if check_type is not UNSET:
            field_dict["check_type"] = check_type
        if time_scale is not UNSET:
            field_dict["time_scale"] = time_scale
        if grouping_columns is not UNSET:
            field_dict["grouping_columns"] = grouping_columns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.table_comparison_grouping_columns_pair_spec import (
            TableComparisonGroupingColumnsPairSpec,
        )

        d = src_dict.copy()
        reference_table_connection_name = d.pop(
            "reference_table_connection_name", UNSET
        )

        reference_table_schema_name = d.pop("reference_table_schema_name", UNSET)

        reference_table_name = d.pop("reference_table_name", UNSET)

        compared_table_filter = d.pop("compared_table_filter", UNSET)

        reference_table_filter = d.pop("reference_table_filter", UNSET)

        _check_type = d.pop("check_type", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        _time_scale = d.pop("time_scale", UNSET)
        time_scale: Union[Unset, CheckTimeScale]
        if isinstance(_time_scale, Unset):
            time_scale = UNSET
        else:
            time_scale = CheckTimeScale(_time_scale)

        grouping_columns = []
        _grouping_columns = d.pop("grouping_columns", UNSET)
        for grouping_columns_item_data in _grouping_columns or []:
            grouping_columns_item = TableComparisonGroupingColumnsPairSpec.from_dict(
                grouping_columns_item_data
            )

            grouping_columns.append(grouping_columns_item)

        table_comparison_configuration_spec = cls(
            reference_table_connection_name=reference_table_connection_name,
            reference_table_schema_name=reference_table_schema_name,
            reference_table_name=reference_table_name,
            compared_table_filter=compared_table_filter,
            reference_table_filter=reference_table_filter,
            check_type=check_type,
            time_scale=time_scale,
            grouping_columns=grouping_columns,
        )

        table_comparison_configuration_spec.additional_properties = d
        return table_comparison_configuration_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_invalid_email_format_found_check_spec import (
        ColumnInvalidEmailFormatFoundCheckSpec,
    )
    from ..models.column_invalid_email_format_percent_check_spec import (
        ColumnInvalidEmailFormatPercentCheckSpec,
    )
    from ..models.column_invalid_ip_4_address_format_found_check_spec import (
        ColumnInvalidIp4AddressFormatFoundCheckSpec,
    )
    from ..models.column_invalid_ip_6_address_format_found_check_spec import (
        ColumnInvalidIp6AddressFormatFoundCheckSpec,
    )
    from ..models.column_invalid_usa_phone_found_check_spec import (
        ColumnInvalidUsaPhoneFoundCheckSpec,
    )
    from ..models.column_invalid_usa_phone_percent_check_spec import (
        ColumnInvalidUsaPhonePercentCheckSpec,
    )
    from ..models.column_invalid_usa_zipcode_found_check_spec import (
        ColumnInvalidUsaZipcodeFoundCheckSpec,
    )
    from ..models.column_invalid_usa_zipcode_percent_check_spec import (
        ColumnInvalidUsaZipcodePercentCheckSpec,
    )
    from ..models.column_invalid_uuid_format_found_check_spec import (
        ColumnInvalidUuidFormatFoundCheckSpec,
    )
    from ..models.column_invalid_uuid_format_percent_check_spec import (
        ColumnInvalidUuidFormatPercentCheckSpec,
    )
    from ..models.column_patterns_profiling_checks_spec_custom_checks import (
        ColumnPatternsProfilingChecksSpecCustomChecks,
    )
    from ..models.column_text_not_matching_date_pattern_found_check_spec import (
        ColumnTextNotMatchingDatePatternFoundCheckSpec,
    )
    from ..models.column_text_not_matching_date_pattern_percent_check_spec import (
        ColumnTextNotMatchingDatePatternPercentCheckSpec,
    )
    from ..models.column_text_not_matching_name_pattern_percent_check_spec import (
        ColumnTextNotMatchingNamePatternPercentCheckSpec,
    )
    from ..models.column_text_not_matching_regex_found_check_spec import (
        ColumnTextNotMatchingRegexFoundCheckSpec,
    )
    from ..models.column_texts_not_matching_regex_percent_check_spec import (
        ColumnTextsNotMatchingRegexPercentCheckSpec,
    )


T = TypeVar("T", bound="ColumnPatternsProfilingChecksSpec")


@_attrs_define
class ColumnPatternsProfilingChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnPatternsProfilingChecksSpecCustomChecks]): Dictionary of additional custom
            checks within this category. The keys are check names defined in the definition section. The sensor parameters
            and rules should match the type of the configured sensor and rule for the custom check.
        profile_text_not_matching_regex_found (Union[Unset, ColumnTextNotMatchingRegexFoundCheckSpec]):
        profile_texts_not_matching_regex_percent (Union[Unset, ColumnTextsNotMatchingRegexPercentCheckSpec]):
        profile_invalid_email_format_found (Union[Unset, ColumnInvalidEmailFormatFoundCheckSpec]):
        profile_invalid_email_format_percent (Union[Unset, ColumnInvalidEmailFormatPercentCheckSpec]):
        profile_text_not_matching_date_pattern_found (Union[Unset, ColumnTextNotMatchingDatePatternFoundCheckSpec]):
        profile_text_not_matching_date_pattern_percent (Union[Unset, ColumnTextNotMatchingDatePatternPercentCheckSpec]):
        profile_text_not_matching_name_pattern_percent (Union[Unset, ColumnTextNotMatchingNamePatternPercentCheckSpec]):
        profile_invalid_uuid_format_found (Union[Unset, ColumnInvalidUuidFormatFoundCheckSpec]):
        profile_invalid_uuid_format_percent (Union[Unset, ColumnInvalidUuidFormatPercentCheckSpec]):
        profile_invalid_ip4_address_format_found (Union[Unset, ColumnInvalidIp4AddressFormatFoundCheckSpec]):
        profile_invalid_ip6_address_format_found (Union[Unset, ColumnInvalidIp6AddressFormatFoundCheckSpec]):
        profile_invalid_usa_phone_format_found (Union[Unset, ColumnInvalidUsaPhoneFoundCheckSpec]):
        profile_invalid_usa_zipcode_format_found (Union[Unset, ColumnInvalidUsaZipcodeFoundCheckSpec]):
        profile_invalid_usa_phone_format_percent (Union[Unset, ColumnInvalidUsaPhonePercentCheckSpec]):
        profile_invalid_usa_zipcode_format_percent (Union[Unset, ColumnInvalidUsaZipcodePercentCheckSpec]):
    """

    custom_checks: Union[Unset, "ColumnPatternsProfilingChecksSpecCustomChecks"] = UNSET
    profile_text_not_matching_regex_found: Union[
        Unset, "ColumnTextNotMatchingRegexFoundCheckSpec"
    ] = UNSET
    profile_texts_not_matching_regex_percent: Union[
        Unset, "ColumnTextsNotMatchingRegexPercentCheckSpec"
    ] = UNSET
    profile_invalid_email_format_found: Union[
        Unset, "ColumnInvalidEmailFormatFoundCheckSpec"
    ] = UNSET
    profile_invalid_email_format_percent: Union[
        Unset, "ColumnInvalidEmailFormatPercentCheckSpec"
    ] = UNSET
    profile_text_not_matching_date_pattern_found: Union[
        Unset, "ColumnTextNotMatchingDatePatternFoundCheckSpec"
    ] = UNSET
    profile_text_not_matching_date_pattern_percent: Union[
        Unset, "ColumnTextNotMatchingDatePatternPercentCheckSpec"
    ] = UNSET
    profile_text_not_matching_name_pattern_percent: Union[
        Unset, "ColumnTextNotMatchingNamePatternPercentCheckSpec"
    ] = UNSET
    profile_invalid_uuid_format_found: Union[
        Unset, "ColumnInvalidUuidFormatFoundCheckSpec"
    ] = UNSET
    profile_invalid_uuid_format_percent: Union[
        Unset, "ColumnInvalidUuidFormatPercentCheckSpec"
    ] = UNSET
    profile_invalid_ip4_address_format_found: Union[
        Unset, "ColumnInvalidIp4AddressFormatFoundCheckSpec"
    ] = UNSET
    profile_invalid_ip6_address_format_found: Union[
        Unset, "ColumnInvalidIp6AddressFormatFoundCheckSpec"
    ] = UNSET
    profile_invalid_usa_phone_format_found: Union[
        Unset, "ColumnInvalidUsaPhoneFoundCheckSpec"
    ] = UNSET
    profile_invalid_usa_zipcode_format_found: Union[
        Unset, "ColumnInvalidUsaZipcodeFoundCheckSpec"
    ] = UNSET
    profile_invalid_usa_phone_format_percent: Union[
        Unset, "ColumnInvalidUsaPhonePercentCheckSpec"
    ] = UNSET
    profile_invalid_usa_zipcode_format_percent: Union[
        Unset, "ColumnInvalidUsaZipcodePercentCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        profile_text_not_matching_regex_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_text_not_matching_regex_found, Unset):
            profile_text_not_matching_regex_found = (
                self.profile_text_not_matching_regex_found.to_dict()
            )

        profile_texts_not_matching_regex_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_texts_not_matching_regex_percent, Unset):
            profile_texts_not_matching_regex_percent = (
                self.profile_texts_not_matching_regex_percent.to_dict()
            )

        profile_invalid_email_format_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_email_format_found, Unset):
            profile_invalid_email_format_found = (
                self.profile_invalid_email_format_found.to_dict()
            )

        profile_invalid_email_format_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_email_format_percent, Unset):
            profile_invalid_email_format_percent = (
                self.profile_invalid_email_format_percent.to_dict()
            )

        profile_text_not_matching_date_pattern_found: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.profile_text_not_matching_date_pattern_found, Unset):
            profile_text_not_matching_date_pattern_found = (
                self.profile_text_not_matching_date_pattern_found.to_dict()
            )

        profile_text_not_matching_date_pattern_percent: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.profile_text_not_matching_date_pattern_percent, Unset):
            profile_text_not_matching_date_pattern_percent = (
                self.profile_text_not_matching_date_pattern_percent.to_dict()
            )

        profile_text_not_matching_name_pattern_percent: Union[Unset, Dict[str, Any]] = (
            UNSET
        )
        if not isinstance(self.profile_text_not_matching_name_pattern_percent, Unset):
            profile_text_not_matching_name_pattern_percent = (
                self.profile_text_not_matching_name_pattern_percent.to_dict()
            )

        profile_invalid_uuid_format_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_uuid_format_found, Unset):
            profile_invalid_uuid_format_found = (
                self.profile_invalid_uuid_format_found.to_dict()
            )

        profile_invalid_uuid_format_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_uuid_format_percent, Unset):
            profile_invalid_uuid_format_percent = (
                self.profile_invalid_uuid_format_percent.to_dict()
            )

        profile_invalid_ip4_address_format_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_ip4_address_format_found, Unset):
            profile_invalid_ip4_address_format_found = (
                self.profile_invalid_ip4_address_format_found.to_dict()
            )

        profile_invalid_ip6_address_format_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_ip6_address_format_found, Unset):
            profile_invalid_ip6_address_format_found = (
                self.profile_invalid_ip6_address_format_found.to_dict()
            )

        profile_invalid_usa_phone_format_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_usa_phone_format_found, Unset):
            profile_invalid_usa_phone_format_found = (
                self.profile_invalid_usa_phone_format_found.to_dict()
            )

        profile_invalid_usa_zipcode_format_found: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_usa_zipcode_format_found, Unset):
            profile_invalid_usa_zipcode_format_found = (
                self.profile_invalid_usa_zipcode_format_found.to_dict()
            )

        profile_invalid_usa_phone_format_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_usa_phone_format_percent, Unset):
            profile_invalid_usa_phone_format_percent = (
                self.profile_invalid_usa_phone_format_percent.to_dict()
            )

        profile_invalid_usa_zipcode_format_percent: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profile_invalid_usa_zipcode_format_percent, Unset):
            profile_invalid_usa_zipcode_format_percent = (
                self.profile_invalid_usa_zipcode_format_percent.to_dict()
            )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if profile_text_not_matching_regex_found is not UNSET:
            field_dict["profile_text_not_matching_regex_found"] = (
                profile_text_not_matching_regex_found
            )
        if profile_texts_not_matching_regex_percent is not UNSET:
            field_dict["profile_texts_not_matching_regex_percent"] = (
                profile_texts_not_matching_regex_percent
            )
        if profile_invalid_email_format_found is not UNSET:
            field_dict["profile_invalid_email_format_found"] = (
                profile_invalid_email_format_found
            )
        if profile_invalid_email_format_percent is not UNSET:
            field_dict["profile_invalid_email_format_percent"] = (
                profile_invalid_email_format_percent
            )
        if profile_text_not_matching_date_pattern_found is not UNSET:
            field_dict["profile_text_not_matching_date_pattern_found"] = (
                profile_text_not_matching_date_pattern_found
            )
        if profile_text_not_matching_date_pattern_percent is not UNSET:
            field_dict["profile_text_not_matching_date_pattern_percent"] = (
                profile_text_not_matching_date_pattern_percent
            )
        if profile_text_not_matching_name_pattern_percent is not UNSET:
            field_dict["profile_text_not_matching_name_pattern_percent"] = (
                profile_text_not_matching_name_pattern_percent
            )
        if profile_invalid_uuid_format_found is not UNSET:
            field_dict["profile_invalid_uuid_format_found"] = (
                profile_invalid_uuid_format_found
            )
        if profile_invalid_uuid_format_percent is not UNSET:
            field_dict["profile_invalid_uuid_format_percent"] = (
                profile_invalid_uuid_format_percent
            )
        if profile_invalid_ip4_address_format_found is not UNSET:
            field_dict["profile_invalid_ip4_address_format_found"] = (
                profile_invalid_ip4_address_format_found
            )
        if profile_invalid_ip6_address_format_found is not UNSET:
            field_dict["profile_invalid_ip6_address_format_found"] = (
                profile_invalid_ip6_address_format_found
            )
        if profile_invalid_usa_phone_format_found is not UNSET:
            field_dict["profile_invalid_usa_phone_format_found"] = (
                profile_invalid_usa_phone_format_found
            )
        if profile_invalid_usa_zipcode_format_found is not UNSET:
            field_dict["profile_invalid_usa_zipcode_format_found"] = (
                profile_invalid_usa_zipcode_format_found
            )
        if profile_invalid_usa_phone_format_percent is not UNSET:
            field_dict["profile_invalid_usa_phone_format_percent"] = (
                profile_invalid_usa_phone_format_percent
            )
        if profile_invalid_usa_zipcode_format_percent is not UNSET:
            field_dict["profile_invalid_usa_zipcode_format_percent"] = (
                profile_invalid_usa_zipcode_format_percent
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_invalid_email_format_found_check_spec import (
            ColumnInvalidEmailFormatFoundCheckSpec,
        )
        from ..models.column_invalid_email_format_percent_check_spec import (
            ColumnInvalidEmailFormatPercentCheckSpec,
        )
        from ..models.column_invalid_ip_4_address_format_found_check_spec import (
            ColumnInvalidIp4AddressFormatFoundCheckSpec,
        )
        from ..models.column_invalid_ip_6_address_format_found_check_spec import (
            ColumnInvalidIp6AddressFormatFoundCheckSpec,
        )
        from ..models.column_invalid_usa_phone_found_check_spec import (
            ColumnInvalidUsaPhoneFoundCheckSpec,
        )
        from ..models.column_invalid_usa_phone_percent_check_spec import (
            ColumnInvalidUsaPhonePercentCheckSpec,
        )
        from ..models.column_invalid_usa_zipcode_found_check_spec import (
            ColumnInvalidUsaZipcodeFoundCheckSpec,
        )
        from ..models.column_invalid_usa_zipcode_percent_check_spec import (
            ColumnInvalidUsaZipcodePercentCheckSpec,
        )
        from ..models.column_invalid_uuid_format_found_check_spec import (
            ColumnInvalidUuidFormatFoundCheckSpec,
        )
        from ..models.column_invalid_uuid_format_percent_check_spec import (
            ColumnInvalidUuidFormatPercentCheckSpec,
        )
        from ..models.column_patterns_profiling_checks_spec_custom_checks import (
            ColumnPatternsProfilingChecksSpecCustomChecks,
        )
        from ..models.column_text_not_matching_date_pattern_found_check_spec import (
            ColumnTextNotMatchingDatePatternFoundCheckSpec,
        )
        from ..models.column_text_not_matching_date_pattern_percent_check_spec import (
            ColumnTextNotMatchingDatePatternPercentCheckSpec,
        )
        from ..models.column_text_not_matching_name_pattern_percent_check_spec import (
            ColumnTextNotMatchingNamePatternPercentCheckSpec,
        )
        from ..models.column_text_not_matching_regex_found_check_spec import (
            ColumnTextNotMatchingRegexFoundCheckSpec,
        )
        from ..models.column_texts_not_matching_regex_percent_check_spec import (
            ColumnTextsNotMatchingRegexPercentCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[Unset, ColumnPatternsProfilingChecksSpecCustomChecks]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = ColumnPatternsProfilingChecksSpecCustomChecks.from_dict(
                _custom_checks
            )

        _profile_text_not_matching_regex_found = d.pop(
            "profile_text_not_matching_regex_found", UNSET
        )
        profile_text_not_matching_regex_found: Union[
            Unset, ColumnTextNotMatchingRegexFoundCheckSpec
        ]
        if isinstance(_profile_text_not_matching_regex_found, Unset):
            profile_text_not_matching_regex_found = UNSET
        else:
            profile_text_not_matching_regex_found = (
                ColumnTextNotMatchingRegexFoundCheckSpec.from_dict(
                    _profile_text_not_matching_regex_found
                )
            )

        _profile_texts_not_matching_regex_percent = d.pop(
            "profile_texts_not_matching_regex_percent", UNSET
        )
        profile_texts_not_matching_regex_percent: Union[
            Unset, ColumnTextsNotMatchingRegexPercentCheckSpec
        ]
        if isinstance(_profile_texts_not_matching_regex_percent, Unset):
            profile_texts_not_matching_regex_percent = UNSET
        else:
            profile_texts_not_matching_regex_percent = (
                ColumnTextsNotMatchingRegexPercentCheckSpec.from_dict(
                    _profile_texts_not_matching_regex_percent
                )
            )

        _profile_invalid_email_format_found = d.pop(
            "profile_invalid_email_format_found", UNSET
        )
        profile_invalid_email_format_found: Union[
            Unset, ColumnInvalidEmailFormatFoundCheckSpec
        ]
        if isinstance(_profile_invalid_email_format_found, Unset):
            profile_invalid_email_format_found = UNSET
        else:
            profile_invalid_email_format_found = (
                ColumnInvalidEmailFormatFoundCheckSpec.from_dict(
                    _profile_invalid_email_format_found
                )
            )

        _profile_invalid_email_format_percent = d.pop(
            "profile_invalid_email_format_percent", UNSET
        )
        profile_invalid_email_format_percent: Union[
            Unset, ColumnInvalidEmailFormatPercentCheckSpec
        ]
        if isinstance(_profile_invalid_email_format_percent, Unset):
            profile_invalid_email_format_percent = UNSET
        else:
            profile_invalid_email_format_percent = (
                ColumnInvalidEmailFormatPercentCheckSpec.from_dict(
                    _profile_invalid_email_format_percent
                )
            )

        _profile_text_not_matching_date_pattern_found = d.pop(
            "profile_text_not_matching_date_pattern_found", UNSET
        )
        profile_text_not_matching_date_pattern_found: Union[
            Unset, ColumnTextNotMatchingDatePatternFoundCheckSpec
        ]
        if isinstance(_profile_text_not_matching_date_pattern_found, Unset):
            profile_text_not_matching_date_pattern_found = UNSET
        else:
            profile_text_not_matching_date_pattern_found = (
                ColumnTextNotMatchingDatePatternFoundCheckSpec.from_dict(
                    _profile_text_not_matching_date_pattern_found
                )
            )

        _profile_text_not_matching_date_pattern_percent = d.pop(
            "profile_text_not_matching_date_pattern_percent", UNSET
        )
        profile_text_not_matching_date_pattern_percent: Union[
            Unset, ColumnTextNotMatchingDatePatternPercentCheckSpec
        ]
        if isinstance(_profile_text_not_matching_date_pattern_percent, Unset):
            profile_text_not_matching_date_pattern_percent = UNSET
        else:
            profile_text_not_matching_date_pattern_percent = (
                ColumnTextNotMatchingDatePatternPercentCheckSpec.from_dict(
                    _profile_text_not_matching_date_pattern_percent
                )
            )

        _profile_text_not_matching_name_pattern_percent = d.pop(
            "profile_text_not_matching_name_pattern_percent", UNSET
        )
        profile_text_not_matching_name_pattern_percent: Union[
            Unset, ColumnTextNotMatchingNamePatternPercentCheckSpec
        ]
        if isinstance(_profile_text_not_matching_name_pattern_percent, Unset):
            profile_text_not_matching_name_pattern_percent = UNSET
        else:
            profile_text_not_matching_name_pattern_percent = (
                ColumnTextNotMatchingNamePatternPercentCheckSpec.from_dict(
                    _profile_text_not_matching_name_pattern_percent
                )
            )

        _profile_invalid_uuid_format_found = d.pop(
            "profile_invalid_uuid_format_found", UNSET
        )
        profile_invalid_uuid_format_found: Union[
            Unset, ColumnInvalidUuidFormatFoundCheckSpec
        ]
        if isinstance(_profile_invalid_uuid_format_found, Unset):
            profile_invalid_uuid_format_found = UNSET
        else:
            profile_invalid_uuid_format_found = (
                ColumnInvalidUuidFormatFoundCheckSpec.from_dict(
                    _profile_invalid_uuid_format_found
                )
            )

        _profile_invalid_uuid_format_percent = d.pop(
            "profile_invalid_uuid_format_percent", UNSET
        )
        profile_invalid_uuid_format_percent: Union[
            Unset, ColumnInvalidUuidFormatPercentCheckSpec
        ]
        if isinstance(_profile_invalid_uuid_format_percent, Unset):
            profile_invalid_uuid_format_percent = UNSET
        else:
            profile_invalid_uuid_format_percent = (
                ColumnInvalidUuidFormatPercentCheckSpec.from_dict(
                    _profile_invalid_uuid_format_percent
                )
            )

        _profile_invalid_ip4_address_format_found = d.pop(
            "profile_invalid_ip4_address_format_found", UNSET
        )
        profile_invalid_ip4_address_format_found: Union[
            Unset, ColumnInvalidIp4AddressFormatFoundCheckSpec
        ]
        if isinstance(_profile_invalid_ip4_address_format_found, Unset):
            profile_invalid_ip4_address_format_found = UNSET
        else:
            profile_invalid_ip4_address_format_found = (
                ColumnInvalidIp4AddressFormatFoundCheckSpec.from_dict(
                    _profile_invalid_ip4_address_format_found
                )
            )

        _profile_invalid_ip6_address_format_found = d.pop(
            "profile_invalid_ip6_address_format_found", UNSET
        )
        profile_invalid_ip6_address_format_found: Union[
            Unset, ColumnInvalidIp6AddressFormatFoundCheckSpec
        ]
        if isinstance(_profile_invalid_ip6_address_format_found, Unset):
            profile_invalid_ip6_address_format_found = UNSET
        else:
            profile_invalid_ip6_address_format_found = (
                ColumnInvalidIp6AddressFormatFoundCheckSpec.from_dict(
                    _profile_invalid_ip6_address_format_found
                )
            )

        _profile_invalid_usa_phone_format_found = d.pop(
            "profile_invalid_usa_phone_format_found", UNSET
        )
        profile_invalid_usa_phone_format_found: Union[
            Unset, ColumnInvalidUsaPhoneFoundCheckSpec
        ]
        if isinstance(_profile_invalid_usa_phone_format_found, Unset):
            profile_invalid_usa_phone_format_found = UNSET
        else:
            profile_invalid_usa_phone_format_found = (
                ColumnInvalidUsaPhoneFoundCheckSpec.from_dict(
                    _profile_invalid_usa_phone_format_found
                )
            )

        _profile_invalid_usa_zipcode_format_found = d.pop(
            "profile_invalid_usa_zipcode_format_found", UNSET
        )
        profile_invalid_usa_zipcode_format_found: Union[
            Unset, ColumnInvalidUsaZipcodeFoundCheckSpec
        ]
        if isinstance(_profile_invalid_usa_zipcode_format_found, Unset):
            profile_invalid_usa_zipcode_format_found = UNSET
        else:
            profile_invalid_usa_zipcode_format_found = (
                ColumnInvalidUsaZipcodeFoundCheckSpec.from_dict(
                    _profile_invalid_usa_zipcode_format_found
                )
            )

        _profile_invalid_usa_phone_format_percent = d.pop(
            "profile_invalid_usa_phone_format_percent", UNSET
        )
        profile_invalid_usa_phone_format_percent: Union[
            Unset, ColumnInvalidUsaPhonePercentCheckSpec
        ]
        if isinstance(_profile_invalid_usa_phone_format_percent, Unset):
            profile_invalid_usa_phone_format_percent = UNSET
        else:
            profile_invalid_usa_phone_format_percent = (
                ColumnInvalidUsaPhonePercentCheckSpec.from_dict(
                    _profile_invalid_usa_phone_format_percent
                )
            )

        _profile_invalid_usa_zipcode_format_percent = d.pop(
            "profile_invalid_usa_zipcode_format_percent", UNSET
        )
        profile_invalid_usa_zipcode_format_percent: Union[
            Unset, ColumnInvalidUsaZipcodePercentCheckSpec
        ]
        if isinstance(_profile_invalid_usa_zipcode_format_percent, Unset):
            profile_invalid_usa_zipcode_format_percent = UNSET
        else:
            profile_invalid_usa_zipcode_format_percent = (
                ColumnInvalidUsaZipcodePercentCheckSpec.from_dict(
                    _profile_invalid_usa_zipcode_format_percent
                )
            )

        column_patterns_profiling_checks_spec = cls(
            custom_checks=custom_checks,
            profile_text_not_matching_regex_found=profile_text_not_matching_regex_found,
            profile_texts_not_matching_regex_percent=profile_texts_not_matching_regex_percent,
            profile_invalid_email_format_found=profile_invalid_email_format_found,
            profile_invalid_email_format_percent=profile_invalid_email_format_percent,
            profile_text_not_matching_date_pattern_found=profile_text_not_matching_date_pattern_found,
            profile_text_not_matching_date_pattern_percent=profile_text_not_matching_date_pattern_percent,
            profile_text_not_matching_name_pattern_percent=profile_text_not_matching_name_pattern_percent,
            profile_invalid_uuid_format_found=profile_invalid_uuid_format_found,
            profile_invalid_uuid_format_percent=profile_invalid_uuid_format_percent,
            profile_invalid_ip4_address_format_found=profile_invalid_ip4_address_format_found,
            profile_invalid_ip6_address_format_found=profile_invalid_ip6_address_format_found,
            profile_invalid_usa_phone_format_found=profile_invalid_usa_phone_format_found,
            profile_invalid_usa_zipcode_format_found=profile_invalid_usa_zipcode_format_found,
            profile_invalid_usa_phone_format_percent=profile_invalid_usa_phone_format_percent,
            profile_invalid_usa_zipcode_format_percent=profile_invalid_usa_zipcode_format_percent,
        )

        column_patterns_profiling_checks_spec.additional_properties = d
        return column_patterns_profiling_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PhysicalTableName")


@_attrs_define
class PhysicalTableName:
    """
    Attributes:
        schema_name (Union[Unset, str]): Schema name
        table_name (Union[Unset, str]): Table name
    """

    schema_name: Union[Unset, str] = UNSET
    table_name: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        schema_name = self.schema_name
        table_name = self.table_name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if schema_name is not UNSET:
            field_dict["schema_name"] = schema_name
        if table_name is not UNSET:
            field_dict["table_name"] = table_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        schema_name = d.pop("schema_name", UNSET)

        table_name = d.pop("table_name", UNSET)

        physical_table_name = cls(
            schema_name=schema_name,
            table_name=table_name,
        )

        physical_table_name.additional_properties = d
        return physical_table_name

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PartitionIncrementalTimeWindowSpec")


@_attrs_define
class PartitionIncrementalTimeWindowSpec:
    """
    Attributes:
        daily_partitioning_recent_days (Union[Unset, int]): The number of recent days analyzed by daily partition checks
            in incremental mode. The default value is 7 last days.
        daily_partitioning_include_today (Union[Unset, bool]): Analyze also today's data by daily partition checks in
            incremental mode. The default value is false, which means that the today's and the future partitions are not
            analyzed. Only yesterday's partition and previous daily partitions are analyzed because today's data may still
            be incomplete. Change the value to 'true' if the current day should also be analyzed. This change may require
            you to configure the schedule for daily checks correctly. The checks must run after the data load.
        monthly_partitioning_recent_months (Union[Unset, int]): The number of recent days analyzed by monthly partition
            checks in incremental mode. The default value is the previous calendar month.
        monthly_partitioning_include_current_month (Union[Unset, bool]): Analyze also this month's data by monthly
            partition checks in incremental mode. The default value is false, which means that the current month is not
            analyzed. Future data is also filtered out because the current month may be incomplete. Change the value to
            'true' if the current month should also be analyzed before the end of the month. This change may require you to
            configure the schedule to run monthly checks more frequently (daily, hourly, etc.).
    """

    daily_partitioning_recent_days: Union[Unset, int] = UNSET
    daily_partitioning_include_today: Union[Unset, bool] = UNSET
    monthly_partitioning_recent_months: Union[Unset, int] = UNSET
    monthly_partitioning_include_current_month: Union[Unset, bool] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        daily_partitioning_recent_days = self.daily_partitioning_recent_days
        daily_partitioning_include_today = self.daily_partitioning_include_today
        monthly_partitioning_recent_months = self.monthly_partitioning_recent_months
        monthly_partitioning_include_current_month = (
            self.monthly_partitioning_include_current_month
        )

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if daily_partitioning_recent_days is not UNSET:
            field_dict["daily_partitioning_recent_days"] = (
                daily_partitioning_recent_days
            )
        if daily_partitioning_include_today is not UNSET:
            field_dict["daily_partitioning_include_today"] = (
                daily_partitioning_include_today
            )
        if monthly_partitioning_recent_months is not UNSET:
            field_dict["monthly_partitioning_recent_months"] = (
                monthly_partitioning_recent_months
            )
        if monthly_partitioning_include_current_month is not UNSET:
            field_dict["monthly_partitioning_include_current_month"] = (
                monthly_partitioning_include_current_month
            )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        daily_partitioning_recent_days = d.pop("daily_partitioning_recent_days", UNSET)

        daily_partitioning_include_today = d.pop(
            "daily_partitioning_include_today", UNSET
        )

        monthly_partitioning_recent_months = d.pop(
            "monthly_partitioning_recent_months", UNSET
        )

        monthly_partitioning_include_current_month = d.pop(
            "monthly_partitioning_include_current_month", UNSET
        )

        partition_incremental_time_window_spec = cls(
            daily_partitioning_recent_days=daily_partitioning_recent_days,
            daily_partitioning_include_today=daily_partitioning_include_today,
            monthly_partitioning_recent_months=monthly_partitioning_recent_months,
            monthly_partitioning_include_current_month=monthly_partitioning_include_current_month,
        )

        partition_incremental_time_window_spec.additional_properties = d
        return partition_incremental_time_window_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.check_results_detailed_load_mode import CheckResultsDetailedLoadMode
from ...models.check_results_list_model import CheckResultsListModel
from ...models.check_time_scale import CheckTimeScale
from ...types import UNSET, Response, Unset


def _get_kwargs(
    connection_name: str,
    schema_name: str,
    table_name: str,
    column_name: str,
    time_scale: CheckTimeScale,
    *,
    data_group: Union[Unset, None, str] = UNSET,
    month_start: Union[Unset, None, datetime.date] = UNSET,
    month_end: Union[Unset, None, datetime.date] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    load_mode: Union[Unset, None, CheckResultsDetailedLoadMode] = UNSET,
    max_results_per_check: Union[Unset, None, int] = UNSET,
) -> Dict[str, Any]:

    pass

    params: Dict[str, Any] = {}
    params["dataGroup"] = data_group

    json_month_start: Union[Unset, None, str] = UNSET
    if not isinstance(month_start, Unset):
        json_month_start = month_start.isoformat() if month_start else None

    params["monthStart"] = json_month_start

    json_month_end: Union[Unset, None, str] = UNSET
    if not isinstance(month_end, Unset):
        json_month_end = month_end.isoformat() if month_end else None

    params["monthEnd"] = json_month_end

    params["checkName"] = check_name

    params["category"] = category

    params["tableComparison"] = table_comparison

    json_load_mode: Union[Unset, None, str] = UNSET
    if not isinstance(load_mode, Unset):
        json_load_mode = load_mode.value if load_mode else None

    params["loadMode"] = json_load_mode

    params["maxResultsPerCheck"] = max_results_per_check

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "api/connections/{connectionName}/schemas/{schemaName}/tables/{tableName}/columns/{columnName}/partitioned/{timeScale}/results".format(
            connectionName=connection_name,
            schemaName=schema_name,
            tableName=table_name,
            columnName=column_name,
            timeScale=time_scale,
        ),
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[List["CheckResultsListModel"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for response_200_item_data in _response_200:
            response_200_item = CheckResultsListModel.from_dict(response_200_item_data)

            response_200.append(response_200_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[List["CheckResultsListModel"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    column_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    data_group: Union[Unset, None, str] = UNSET,
    month_start: Union[Unset, None, datetime.date] = UNSET,
    month_end: Union[Unset, None, datetime.date] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    load_mode: Union[Unset, None, CheckResultsDetailedLoadMode] = UNSET,
    max_results_per_check: Union[Unset, None, int] = UNSET,
) -> Response[List["CheckResultsListModel"]]:
    """getColumnPartitionedChecksResults

     Returns an overview of the most recent column level partitioned checks executions for a requested
    time scale

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        column_name (str):
        time_scale (CheckTimeScale):
        data_group (Union[Unset, None, str]):
        month_start (Union[Unset, None, datetime.date]):
        month_end (Union[Unset, None, datetime.date]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        load_mode (Union[Unset, None, CheckResultsDetailedLoadMode]):
        max_results_per_check (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['CheckResultsListModel']]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        column_name=column_name,
        time_scale=time_scale,
        data_group=data_group,
        month_start=month_start,
        month_end=month_end,
        check_name=check_name,
        category=category,
        table_comparison=table_comparison,
        load_mode=load_mode,
        max_results_per_check=max_results_per_check,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    connection_name: str,
    schema_name: str,
    table_name: str,
    column_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    data_group: Union[Unset, None, str] = UNSET,
    month_start: Union[Unset, None, datetime.date] = UNSET,
    month_end: Union[Unset, None, datetime.date] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    load_mode: Union[Unset, None, CheckResultsDetailedLoadMode] = UNSET,
    max_results_per_check: Union[Unset, None, int] = UNSET,
) -> Optional[List["CheckResultsListModel"]]:
    """getColumnPartitionedChecksResults

     Returns an overview of the most recent column level partitioned checks executions for a requested
    time scale

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        column_name (str):
        time_scale (CheckTimeScale):
        data_group (Union[Unset, None, str]):
        month_start (Union[Unset, None, datetime.date]):
        month_end (Union[Unset, None, datetime.date]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        load_mode (Union[Unset, None, CheckResultsDetailedLoadMode]):
        max_results_per_check (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['CheckResultsListModel']
    """

    return sync_detailed(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        column_name=column_name,
        time_scale=time_scale,
        client=client,
        data_group=data_group,
        month_start=month_start,
        month_end=month_end,
        check_name=check_name,
        category=category,
        table_comparison=table_comparison,
        load_mode=load_mode,
        max_results_per_check=max_results_per_check,
    ).parsed


async def asyncio_detailed(
    connection_name: str,
    schema_name: str,
    table_name: str,
    column_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    data_group: Union[Unset, None, str] = UNSET,
    month_start: Union[Unset, None, datetime.date] = UNSET,
    month_end: Union[Unset, None, datetime.date] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    load_mode: Union[Unset, None, CheckResultsDetailedLoadMode] = UNSET,
    max_results_per_check: Union[Unset, None, int] = UNSET,
) -> Response[List["CheckResultsListModel"]]:
    """getColumnPartitionedChecksResults

     Returns an overview of the most recent column level partitioned checks executions for a requested
    time scale

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        column_name (str):
        time_scale (CheckTimeScale):
        data_group (Union[Unset, None, str]):
        month_start (Union[Unset, None, datetime.date]):
        month_end (Union[Unset, None, datetime.date]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        load_mode (Union[Unset, None, CheckResultsDetailedLoadMode]):
        max_results_per_check (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['CheckResultsListModel']]
    """

    kwargs = _get_kwargs(
        connection_name=connection_name,
        schema_name=schema_name,
        table_name=table_name,
        column_name=column_name,
        time_scale=time_scale,
        data_group=data_group,
        month_start=month_start,
        month_end=month_end,
        check_name=check_name,
        category=category,
        table_comparison=table_comparison,
        load_mode=load_mode,
        max_results_per_check=max_results_per_check,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    connection_name: str,
    schema_name: str,
    table_name: str,
    column_name: str,
    time_scale: CheckTimeScale,
    *,
    client: AuthenticatedClient,
    data_group: Union[Unset, None, str] = UNSET,
    month_start: Union[Unset, None, datetime.date] = UNSET,
    month_end: Union[Unset, None, datetime.date] = UNSET,
    check_name: Union[Unset, None, str] = UNSET,
    category: Union[Unset, None, str] = UNSET,
    table_comparison: Union[Unset, None, str] = UNSET,
    load_mode: Union[Unset, None, CheckResultsDetailedLoadMode] = UNSET,
    max_results_per_check: Union[Unset, None, int] = UNSET,
) -> Optional[List["CheckResultsListModel"]]:
    """getColumnPartitionedChecksResults

     Returns an overview of the most recent column level partitioned checks executions for a requested
    time scale

    Args:
        connection_name (str):
        schema_name (str):
        table_name (str):
        column_name (str):
        time_scale (CheckTimeScale):
        data_group (Union[Unset, None, str]):
        month_start (Union[Unset, None, datetime.date]):
        month_end (Union[Unset, None, datetime.date]):
        check_name (Union[Unset, None, str]):
        category (Union[Unset, None, str]):
        table_comparison (Union[Unset, None, str]):
        load_mode (Union[Unset, None, CheckResultsDetailedLoadMode]):
        max_results_per_check (Union[Unset, None, int]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        List['CheckResultsListModel']
    """

    return (
        await asyncio_detailed(
            connection_name=connection_name,
            schema_name=schema_name,
            table_name=table_name,
            column_name=column_name,
            time_scale=time_scale,
            client=client,
            data_group=data_group,
            month_start=month_start,
            month_end=month_end,
            check_name=check_name,
            category=category,
            table_comparison=table_comparison,
            load_mode=load_mode,
            max_results_per_check=max_results_per_check,
        )
    ).parsed



from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.dqo_user_role import DqoUserRole

T = TypeVar("T", bound="DqoUserRolesModelDataDomainRoles")


@_attrs_define
class DqoUserRolesModelDataDomainRoles:
    """User roles within each data domain. Data domains are supported in an ENTERPRISE version of DQOps and they are
    managed by the SaaS components of DQOps Cloud.

    """

    additional_properties: Dict[str, DqoUserRole] = _attrs_field(
        init=False, factory=dict
    )

    def to_dict(self) -> Dict[str, Any]:

        field_dict: Dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = prop.value

        field_dict.update({})

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        dqo_user_roles_model_data_domain_roles = cls()

        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = DqoUserRole(prop_dict)

            additional_properties[prop_name] = additional_property

        dqo_user_roles_model_data_domain_roles.additional_properties = (
            additional_properties
        )
        return dqo_user_roles_model_data_domain_roles

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> DqoUserRole:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: DqoUserRole) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.column_comparison_max_match_check_spec import (
        ColumnComparisonMaxMatchCheckSpec,
    )
    from ..models.column_comparison_mean_match_check_spec import (
        ColumnComparisonMeanMatchCheckSpec,
    )
    from ..models.column_comparison_min_match_check_spec import (
        ColumnComparisonMinMatchCheckSpec,
    )
    from ..models.column_comparison_monthly_monitoring_checks_spec_custom_checks import (
        ColumnComparisonMonthlyMonitoringChecksSpecCustomChecks,
    )
    from ..models.column_comparison_not_null_count_match_check_spec import (
        ColumnComparisonNotNullCountMatchCheckSpec,
    )
    from ..models.column_comparison_null_count_match_check_spec import (
        ColumnComparisonNullCountMatchCheckSpec,
    )
    from ..models.column_comparison_sum_match_check_spec import (
        ColumnComparisonSumMatchCheckSpec,
    )


T = TypeVar("T", bound="ColumnComparisonMonthlyMonitoringChecksSpec")


@_attrs_define
class ColumnComparisonMonthlyMonitoringChecksSpec:
    """
    Attributes:
        custom_checks (Union[Unset, ColumnComparisonMonthlyMonitoringChecksSpecCustomChecks]): Dictionary of additional
            custom checks within this category. The keys are check names defined in the definition section. The sensor
            parameters and rules should match the type of the configured sensor and rule for the custom check.
        reference_column (Union[Unset, str]): The name of the reference column name in the reference table. It is the
            column to which the current column is compared to.
        monthly_sum_match (Union[Unset, ColumnComparisonSumMatchCheckSpec]):
        monthly_min_match (Union[Unset, ColumnComparisonMinMatchCheckSpec]):
        monthly_max_match (Union[Unset, ColumnComparisonMaxMatchCheckSpec]):
        monthly_mean_match (Union[Unset, ColumnComparisonMeanMatchCheckSpec]):
        monthly_not_null_count_match (Union[Unset, ColumnComparisonNotNullCountMatchCheckSpec]):
        monthly_null_count_match (Union[Unset, ColumnComparisonNullCountMatchCheckSpec]):
    """

    custom_checks: Union[
        Unset, "ColumnComparisonMonthlyMonitoringChecksSpecCustomChecks"
    ] = UNSET
    reference_column: Union[Unset, str] = UNSET
    monthly_sum_match: Union[Unset, "ColumnComparisonSumMatchCheckSpec"] = UNSET
    monthly_min_match: Union[Unset, "ColumnComparisonMinMatchCheckSpec"] = UNSET
    monthly_max_match: Union[Unset, "ColumnComparisonMaxMatchCheckSpec"] = UNSET
    monthly_mean_match: Union[Unset, "ColumnComparisonMeanMatchCheckSpec"] = UNSET
    monthly_not_null_count_match: Union[
        Unset, "ColumnComparisonNotNullCountMatchCheckSpec"
    ] = UNSET
    monthly_null_count_match: Union[
        Unset, "ColumnComparisonNullCountMatchCheckSpec"
    ] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        custom_checks: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_checks, Unset):
            custom_checks = self.custom_checks.to_dict()

        reference_column = self.reference_column
        monthly_sum_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_sum_match, Unset):
            monthly_sum_match = self.monthly_sum_match.to_dict()

        monthly_min_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_min_match, Unset):
            monthly_min_match = self.monthly_min_match.to_dict()

        monthly_max_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_max_match, Unset):
            monthly_max_match = self.monthly_max_match.to_dict()

        monthly_mean_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_mean_match, Unset):
            monthly_mean_match = self.monthly_mean_match.to_dict()

        monthly_not_null_count_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_not_null_count_match, Unset):
            monthly_not_null_count_match = self.monthly_not_null_count_match.to_dict()

        monthly_null_count_match: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monthly_null_count_match, Unset):
            monthly_null_count_match = self.monthly_null_count_match.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if custom_checks is not UNSET:
            field_dict["custom_checks"] = custom_checks
        if reference_column is not UNSET:
            field_dict["reference_column"] = reference_column
        if monthly_sum_match is not UNSET:
            field_dict["monthly_sum_match"] = monthly_sum_match
        if monthly_min_match is not UNSET:
            field_dict["monthly_min_match"] = monthly_min_match
        if monthly_max_match is not UNSET:
            field_dict["monthly_max_match"] = monthly_max_match
        if monthly_mean_match is not UNSET:
            field_dict["monthly_mean_match"] = monthly_mean_match
        if monthly_not_null_count_match is not UNSET:
            field_dict["monthly_not_null_count_match"] = monthly_not_null_count_match
        if monthly_null_count_match is not UNSET:
            field_dict["monthly_null_count_match"] = monthly_null_count_match

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.column_comparison_max_match_check_spec import (
            ColumnComparisonMaxMatchCheckSpec,
        )
        from ..models.column_comparison_mean_match_check_spec import (
            ColumnComparisonMeanMatchCheckSpec,
        )
        from ..models.column_comparison_min_match_check_spec import (
            ColumnComparisonMinMatchCheckSpec,
        )
        from ..models.column_comparison_monthly_monitoring_checks_spec_custom_checks import (
            ColumnComparisonMonthlyMonitoringChecksSpecCustomChecks,
        )
        from ..models.column_comparison_not_null_count_match_check_spec import (
            ColumnComparisonNotNullCountMatchCheckSpec,
        )
        from ..models.column_comparison_null_count_match_check_spec import (
            ColumnComparisonNullCountMatchCheckSpec,
        )
        from ..models.column_comparison_sum_match_check_spec import (
            ColumnComparisonSumMatchCheckSpec,
        )

        d = src_dict.copy()
        _custom_checks = d.pop("custom_checks", UNSET)
        custom_checks: Union[
            Unset, ColumnComparisonMonthlyMonitoringChecksSpecCustomChecks
        ]
        if isinstance(_custom_checks, Unset):
            custom_checks = UNSET
        else:
            custom_checks = (
                ColumnComparisonMonthlyMonitoringChecksSpecCustomChecks.from_dict(
                    _custom_checks
                )
            )

        reference_column = d.pop("reference_column", UNSET)

        _monthly_sum_match = d.pop("monthly_sum_match", UNSET)
        monthly_sum_match: Union[Unset, ColumnComparisonSumMatchCheckSpec]
        if isinstance(_monthly_sum_match, Unset):
            monthly_sum_match = UNSET
        else:
            monthly_sum_match = ColumnComparisonSumMatchCheckSpec.from_dict(
                _monthly_sum_match
            )

        _monthly_min_match = d.pop("monthly_min_match", UNSET)
        monthly_min_match: Union[Unset, ColumnComparisonMinMatchCheckSpec]
        if isinstance(_monthly_min_match, Unset):
            monthly_min_match = UNSET
        else:
            monthly_min_match = ColumnComparisonMinMatchCheckSpec.from_dict(
                _monthly_min_match
            )

        _monthly_max_match = d.pop("monthly_max_match", UNSET)
        monthly_max_match: Union[Unset, ColumnComparisonMaxMatchCheckSpec]
        if isinstance(_monthly_max_match, Unset):
            monthly_max_match = UNSET
        else:
            monthly_max_match = ColumnComparisonMaxMatchCheckSpec.from_dict(
                _monthly_max_match
            )

        _monthly_mean_match = d.pop("monthly_mean_match", UNSET)
        monthly_mean_match: Union[Unset, ColumnComparisonMeanMatchCheckSpec]
        if isinstance(_monthly_mean_match, Unset):
            monthly_mean_match = UNSET
        else:
            monthly_mean_match = ColumnComparisonMeanMatchCheckSpec.from_dict(
                _monthly_mean_match
            )

        _monthly_not_null_count_match = d.pop("monthly_not_null_count_match", UNSET)
        monthly_not_null_count_match: Union[
            Unset, ColumnComparisonNotNullCountMatchCheckSpec
        ]
        if isinstance(_monthly_not_null_count_match, Unset):
            monthly_not_null_count_match = UNSET
        else:
            monthly_not_null_count_match = (
                ColumnComparisonNotNullCountMatchCheckSpec.from_dict(
                    _monthly_not_null_count_match
                )
            )

        _monthly_null_count_match = d.pop("monthly_null_count_match", UNSET)
        monthly_null_count_match: Union[Unset, ColumnComparisonNullCountMatchCheckSpec]
        if isinstance(_monthly_null_count_match, Unset):
            monthly_null_count_match = UNSET
        else:
            monthly_null_count_match = (
                ColumnComparisonNullCountMatchCheckSpec.from_dict(
                    _monthly_null_count_match
                )
            )

        column_comparison_monthly_monitoring_checks_spec = cls(
            custom_checks=custom_checks,
            reference_column=reference_column,
            monthly_sum_match=monthly_sum_match,
            monthly_min_match=monthly_min_match,
            monthly_max_match=monthly_max_match,
            monthly_mean_match=monthly_mean_match,
            monthly_not_null_count_match=monthly_not_null_count_match,
            monthly_null_count_match=monthly_null_count_match,
        )

        column_comparison_monthly_monitoring_checks_spec.additional_properties = d
        return column_comparison_monthly_monitoring_checks_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.incident_filtered_notification_location import (
    IncidentFilteredNotificationLocation,
)
from ..models.incident_status import IncidentStatus
from ..types import UNSET, Unset

T = TypeVar("T", bound="IncidentModel")


@_attrs_define
class IncidentModel:
    """
    Attributes:
        incident_id (Union[Unset, str]): Incident ID - the primary key that identifies each data quality incident.
        connection (Union[Unset, str]): Connection name affected by a data quality incident.
        year (Union[Unset, int]): The year when the incident was first seen. This value is required to load an
            incident's monthly partition.
        month (Union[Unset, int]): The month when the incident was first seen. This value is required to load an
            incident's monthly partition.
        schema (Union[Unset, str]): Schema name affected by a data quality incident.
        table (Union[Unset, str]): Table name affected by a data quality incident.
        table_priority (Union[Unset, int]): Table priority of the table that was affected by a data quality incident.
        incident_hash (Union[Unset, int]): Data quality incident hash that identifies similar incidents on the same
            incident grouping level.
        first_seen (Union[Unset, int]): The UTC timestamp when the data quality incident was first seen.
        last_seen (Union[Unset, int]): The UTC timestamp when the data quality incident was last seen.
        incident_until (Union[Unset, int]): The UTC timestamp when the data quality incident is valid until. All new
            failed data quality check results until that date will be included in this incident, unless the incident status
            is changed to resolved, so a new incident must be created.
        data_group (Union[Unset, str]): The data group that was affected by a data quality incident.
        quality_dimension (Union[Unset, str]): The data quality dimension that was affected by a data quality incident.
        check_category (Union[Unset, str]): The data quality check category that was affected by a data quality
            incident.
        check_type (Union[Unset, str]): The data quality check type that was affected by a data quality incident.
        check_name (Union[Unset, str]): The data quality check name that was affected by a data quality incident.
        highest_severity (Union[Unset, int]): The highest failed check severity that was detected as part of this data
            quality incident. Possible values are: 1 - warning, 2 - error, 3 - fatal.
        minimum_severity (Union[Unset, int]): The minimum severity of the data quality incident, copied from the
            incident configuration at a connection or table at the time when the incident was first seen. Possible values
            are: 1 - warning, 2 - error, 3 - fatal.
        failed_checks_count (Union[Unset, int]): The total number of failed data quality checks that were seen when the
            incident was raised for the first time.
        issue_url (Union[Unset, str]): The link (url) to a ticket in an external system that is tracking this incident.
        status (Union[Unset, IncidentStatus]):
        notification_name (Union[Unset, str]): Matching filtered notification for this incident.
        notification_location (Union[Unset, IncidentFilteredNotificationLocation]):
    """

    incident_id: Union[Unset, str] = UNSET
    connection: Union[Unset, str] = UNSET
    year: Union[Unset, int] = UNSET
    month: Union[Unset, int] = UNSET
    schema: Union[Unset, str] = UNSET
    table: Union[Unset, str] = UNSET
    table_priority: Union[Unset, int] = UNSET
    incident_hash: Union[Unset, int] = UNSET
    first_seen: Union[Unset, int] = UNSET
    last_seen: Union[Unset, int] = UNSET
    incident_until: Union[Unset, int] = UNSET
    data_group: Union[Unset, str] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    check_category: Union[Unset, str] = UNSET
    check_type: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    highest_severity: Union[Unset, int] = UNSET
    minimum_severity: Union[Unset, int] = UNSET
    failed_checks_count: Union[Unset, int] = UNSET
    issue_url: Union[Unset, str] = UNSET
    status: Union[Unset, IncidentStatus] = UNSET
    notification_name: Union[Unset, str] = UNSET
    notification_location: Union[Unset, IncidentFilteredNotificationLocation] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        incident_id = self.incident_id
        connection = self.connection
        year = self.year
        month = self.month
        schema = self.schema
        table = self.table
        table_priority = self.table_priority
        incident_hash = self.incident_hash
        first_seen = self.first_seen
        last_seen = self.last_seen
        incident_until = self.incident_until
        data_group = self.data_group
        quality_dimension = self.quality_dimension
        check_category = self.check_category
        check_type = self.check_type
        check_name = self.check_name
        highest_severity = self.highest_severity
        minimum_severity = self.minimum_severity
        failed_checks_count = self.failed_checks_count
        issue_url = self.issue_url
        status: Union[Unset, str] = UNSET
        if not isinstance(self.status, Unset):
            status = self.status.value

        notification_name = self.notification_name
        notification_location: Union[Unset, str] = UNSET
        if not isinstance(self.notification_location, Unset):
            notification_location = self.notification_location.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if incident_id is not UNSET:
            field_dict["incidentId"] = incident_id
        if connection is not UNSET:
            field_dict["connection"] = connection
        if year is not UNSET:
            field_dict["year"] = year
        if month is not UNSET:
            field_dict["month"] = month
        if schema is not UNSET:
            field_dict["schema"] = schema
        if table is not UNSET:
            field_dict["table"] = table
        if table_priority is not UNSET:
            field_dict["tablePriority"] = table_priority
        if incident_hash is not UNSET:
            field_dict["incidentHash"] = incident_hash
        if first_seen is not UNSET:
            field_dict["firstSeen"] = first_seen
        if last_seen is not UNSET:
            field_dict["lastSeen"] = last_seen
        if incident_until is not UNSET:
            field_dict["incidentUntil"] = incident_until
        if data_group is not UNSET:
            field_dict["dataGroup"] = data_group
        if quality_dimension is not UNSET:
            field_dict["qualityDimension"] = quality_dimension
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if highest_severity is not UNSET:
            field_dict["highestSeverity"] = highest_severity
        if minimum_severity is not UNSET:
            field_dict["minimumSeverity"] = minimum_severity
        if failed_checks_count is not UNSET:
            field_dict["failedChecksCount"] = failed_checks_count
        if issue_url is not UNSET:
            field_dict["issueUrl"] = issue_url
        if status is not UNSET:
            field_dict["status"] = status
        if notification_name is not UNSET:
            field_dict["notificationName"] = notification_name
        if notification_location is not UNSET:
            field_dict["notificationLocation"] = notification_location

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        incident_id = d.pop("incidentId", UNSET)

        connection = d.pop("connection", UNSET)

        year = d.pop("year", UNSET)

        month = d.pop("month", UNSET)

        schema = d.pop("schema", UNSET)

        table = d.pop("table", UNSET)

        table_priority = d.pop("tablePriority", UNSET)

        incident_hash = d.pop("incidentHash", UNSET)

        first_seen = d.pop("firstSeen", UNSET)

        last_seen = d.pop("lastSeen", UNSET)

        incident_until = d.pop("incidentUntil", UNSET)

        data_group = d.pop("dataGroup", UNSET)

        quality_dimension = d.pop("qualityDimension", UNSET)

        check_category = d.pop("checkCategory", UNSET)

        check_type = d.pop("checkType", UNSET)

        check_name = d.pop("checkName", UNSET)

        highest_severity = d.pop("highestSeverity", UNSET)

        minimum_severity = d.pop("minimumSeverity", UNSET)

        failed_checks_count = d.pop("failedChecksCount", UNSET)

        issue_url = d.pop("issueUrl", UNSET)

        _status = d.pop("status", UNSET)
        status: Union[Unset, IncidentStatus]
        if isinstance(_status, Unset):
            status = UNSET
        else:
            status = IncidentStatus(_status)

        notification_name = d.pop("notificationName", UNSET)

        _notification_location = d.pop("notificationLocation", UNSET)
        notification_location: Union[Unset, IncidentFilteredNotificationLocation]
        if isinstance(_notification_location, Unset):
            notification_location = UNSET
        else:
            notification_location = IncidentFilteredNotificationLocation(
                _notification_location
            )

        incident_model = cls(
            incident_id=incident_id,
            connection=connection,
            year=year,
            month=month,
            schema=schema,
            table=table,
            table_priority=table_priority,
            incident_hash=incident_hash,
            first_seen=first_seen,
            last_seen=last_seen,
            incident_until=incident_until,
            data_group=data_group,
            quality_dimension=quality_dimension,
            check_category=check_category,
            check_type=check_type,
            check_name=check_name,
            highest_severity=highest_severity,
            minimum_severity=minimum_severity,
            failed_checks_count=failed_checks_count,
            issue_url=issue_url,
            status=status,
            notification_name=notification_name,
            notification_location=notification_location,
        )

        incident_model.additional_properties = d
        return incident_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field
from dateutil.parser import isoparse

from ..models.check_type import CheckType
from ..models.time_period_gradient import TimePeriodGradient
from ..types import UNSET, Unset

T = TypeVar("T", bound="CheckResultEntryModel")


@_attrs_define
class CheckResultEntryModel:
    """
    Attributes:
        id (Union[Unset, str]): Check result primary key
        check_hash (Union[Unset, int]): Check hash, do not set a value when writing results to DQOps
        check_category (Union[Unset, str]): Check category name
        check_name (Union[Unset, str]): Check name
        check_display_name (Union[Unset, str]): Check display name
        check_type (Union[Unset, CheckType]):
        actual_value (Union[Unset, float]): Actual value
        expected_value (Union[Unset, float]): Expected value
        warning_lower_bound (Union[Unset, float]): Warning lower bound
        warning_upper_bound (Union[Unset, float]): Warning upper bound
        error_lower_bound (Union[Unset, float]): Error lower bound
        error_upper_bound (Union[Unset, float]): Error upper bound
        fatal_lower_bound (Union[Unset, float]): Fatal lower bound
        fatal_upper_bound (Union[Unset, float]): Fatal upper bound
        severity (Union[Unset, int]): Issue severity, 0 - valid, 1 - warning, 2 - error, 3 - fatal
        column_name (Union[Unset, str]): Column name
        data_group (Union[Unset, str]): Data group name
        duration_ms (Union[Unset, int]): Duration (ms)
        executed_at (Union[Unset, int]): Executed at timestamp
        time_gradient (Union[Unset, TimePeriodGradient]):
        time_period (Union[Unset, datetime.datetime]): Time period
        include_in_kpi (Union[Unset, bool]): Include in KPI
        include_in_sla (Union[Unset, bool]): Include in SLA
        provider (Union[Unset, str]): Provider name
        quality_dimension (Union[Unset, str]): Data quality dimension
        sensor_name (Union[Unset, str]): Sensor name
        table_comparison (Union[Unset, str]): Table comparison name
        updated_at (Union[Unset, int]): The timestamp when the check was recently updated with a new value because it as
            rerun for the same period and the severity could be changed
    """

    id: Union[Unset, str] = UNSET
    check_hash: Union[Unset, int] = UNSET
    check_category: Union[Unset, str] = UNSET
    check_name: Union[Unset, str] = UNSET
    check_display_name: Union[Unset, str] = UNSET
    check_type: Union[Unset, CheckType] = UNSET
    actual_value: Union[Unset, float] = UNSET
    expected_value: Union[Unset, float] = UNSET
    warning_lower_bound: Union[Unset, float] = UNSET
    warning_upper_bound: Union[Unset, float] = UNSET
    error_lower_bound: Union[Unset, float] = UNSET
    error_upper_bound: Union[Unset, float] = UNSET
    fatal_lower_bound: Union[Unset, float] = UNSET
    fatal_upper_bound: Union[Unset, float] = UNSET
    severity: Union[Unset, int] = UNSET
    column_name: Union[Unset, str] = UNSET
    data_group: Union[Unset, str] = UNSET
    duration_ms: Union[Unset, int] = UNSET
    executed_at: Union[Unset, int] = UNSET
    time_gradient: Union[Unset, TimePeriodGradient] = UNSET
    time_period: Union[Unset, datetime.datetime] = UNSET
    include_in_kpi: Union[Unset, bool] = UNSET
    include_in_sla: Union[Unset, bool] = UNSET
    provider: Union[Unset, str] = UNSET
    quality_dimension: Union[Unset, str] = UNSET
    sensor_name: Union[Unset, str] = UNSET
    table_comparison: Union[Unset, str] = UNSET
    updated_at: Union[Unset, int] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        check_hash = self.check_hash
        check_category = self.check_category
        check_name = self.check_name
        check_display_name = self.check_display_name
        check_type: Union[Unset, str] = UNSET
        if not isinstance(self.check_type, Unset):
            check_type = self.check_type.value

        actual_value = self.actual_value
        expected_value = self.expected_value
        warning_lower_bound = self.warning_lower_bound
        warning_upper_bound = self.warning_upper_bound
        error_lower_bound = self.error_lower_bound
        error_upper_bound = self.error_upper_bound
        fatal_lower_bound = self.fatal_lower_bound
        fatal_upper_bound = self.fatal_upper_bound
        severity = self.severity
        column_name = self.column_name
        data_group = self.data_group
        duration_ms = self.duration_ms
        executed_at = self.executed_at
        time_gradient: Union[Unset, str] = UNSET
        if not isinstance(self.time_gradient, Unset):
            time_gradient = self.time_gradient.value

        time_period: Union[Unset, str] = UNSET
        if not isinstance(self.time_period, Unset):
            time_period = self.time_period.isoformat()

        include_in_kpi = self.include_in_kpi
        include_in_sla = self.include_in_sla
        provider = self.provider
        quality_dimension = self.quality_dimension
        sensor_name = self.sensor_name
        table_comparison = self.table_comparison
        updated_at = self.updated_at

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if check_hash is not UNSET:
            field_dict["checkHash"] = check_hash
        if check_category is not UNSET:
            field_dict["checkCategory"] = check_category
        if check_name is not UNSET:
            field_dict["checkName"] = check_name
        if check_display_name is not UNSET:
            field_dict["checkDisplayName"] = check_display_name
        if check_type is not UNSET:
            field_dict["checkType"] = check_type
        if actual_value is not UNSET:
            field_dict["actualValue"] = actual_value
        if expected_value is not UNSET:
            field_dict["expectedValue"] = expected_value
        if warning_lower_bound is not UNSET:
            field_dict["warningLowerBound"] = warning_lower_bound
        if warning_upper_bound is not UNSET:
            field_dict["warningUpperBound"] = warning_upper_bound
        if error_lower_bound is not UNSET:
            field_dict["errorLowerBound"] = error_lower_bound
        if error_upper_bound is not UNSET:
            field_dict["errorUpperBound"] = error_upper_bound
        if fatal_lower_bound is not UNSET:
            field_dict["fatalLowerBound"] = fatal_lower_bound
        if fatal_upper_bound is not UNSET:
            field_dict["fatalUpperBound"] = fatal_upper_bound
        if severity is not UNSET:
            field_dict["severity"] = severity
        if column_name is not UNSET:
            field_dict["columnName"] = column_name
        if data_group is not UNSET:
            field_dict["dataGroup"] = data_group
        if duration_ms is not UNSET:
            field_dict["durationMs"] = duration_ms
        if executed_at is not UNSET:
            field_dict["executedAt"] = executed_at
        if time_gradient is not UNSET:
            field_dict["timeGradient"] = time_gradient
        if time_period is not UNSET:
            field_dict["timePeriod"] = time_period
        if include_in_kpi is not UNSET:
            field_dict["includeInKpi"] = include_in_kpi
        if include_in_sla is not UNSET:
            field_dict["includeInSla"] = include_in_sla
        if provider is not UNSET:
            field_dict["provider"] = provider
        if quality_dimension is not UNSET:
            field_dict["qualityDimension"] = quality_dimension
        if sensor_name is not UNSET:
            field_dict["sensorName"] = sensor_name
        if table_comparison is not UNSET:
            field_dict["tableComparison"] = table_comparison
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("id", UNSET)

        check_hash = d.pop("checkHash", UNSET)

        check_category = d.pop("checkCategory", UNSET)

        check_name = d.pop("checkName", UNSET)

        check_display_name = d.pop("checkDisplayName", UNSET)

        _check_type = d.pop("checkType", UNSET)
        check_type: Union[Unset, CheckType]
        if isinstance(_check_type, Unset):
            check_type = UNSET
        else:
            check_type = CheckType(_check_type)

        actual_value = d.pop("actualValue", UNSET)

        expected_value = d.pop("expectedValue", UNSET)

        warning_lower_bound = d.pop("warningLowerBound", UNSET)

        warning_upper_bound = d.pop("warningUpperBound", UNSET)

        error_lower_bound = d.pop("errorLowerBound", UNSET)

        error_upper_bound = d.pop("errorUpperBound", UNSET)

        fatal_lower_bound = d.pop("fatalLowerBound", UNSET)

        fatal_upper_bound = d.pop("fatalUpperBound", UNSET)

        severity = d.pop("severity", UNSET)

        column_name = d.pop("columnName", UNSET)

        data_group = d.pop("dataGroup", UNSET)

        duration_ms = d.pop("durationMs", UNSET)

        executed_at = d.pop("executedAt", UNSET)

        _time_gradient = d.pop("timeGradient", UNSET)
        time_gradient: Union[Unset, TimePeriodGradient]
        if isinstance(_time_gradient, Unset):
            time_gradient = UNSET
        else:
            time_gradient = TimePeriodGradient(_time_gradient)

        _time_period = d.pop("timePeriod", UNSET)
        time_period: Union[Unset, datetime.datetime]
        if isinstance(_time_period, Unset):
            time_period = UNSET
        else:
            time_period = isoparse(_time_period)

        include_in_kpi = d.pop("includeInKpi", UNSET)

        include_in_sla = d.pop("includeInSla", UNSET)

        provider = d.pop("provider", UNSET)

        quality_dimension = d.pop("qualityDimension", UNSET)

        sensor_name = d.pop("sensorName", UNSET)

        table_comparison = d.pop("tableComparison", UNSET)

        updated_at = d.pop("updatedAt", UNSET)

        check_result_entry_model = cls(
            id=id,
            check_hash=check_hash,
            check_category=check_category,
            check_name=check_name,
            check_display_name=check_display_name,
            check_type=check_type,
            actual_value=actual_value,
            expected_value=expected_value,
            warning_lower_bound=warning_lower_bound,
            warning_upper_bound=warning_upper_bound,
            error_lower_bound=error_lower_bound,
            error_upper_bound=error_upper_bound,
            fatal_lower_bound=fatal_lower_bound,
            fatal_upper_bound=fatal_upper_bound,
            severity=severity,
            column_name=column_name,
            data_group=data_group,
            duration_ms=duration_ms,
            executed_at=executed_at,
            time_gradient=time_gradient,
            time_period=time_period,
            include_in_kpi=include_in_kpi,
            include_in_sla=include_in_sla,
            provider=provider,
            quality_dimension=quality_dimension,
            sensor_name=sensor_name,
            table_comparison=table_comparison,
            updated_at=updated_at,
        )

        check_result_entry_model.additional_properties = d
        return check_result_entry_model

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class EffectiveScheduleLevelModel(str, Enum):
    CHECK_OVERRIDE = "check_override"
    CONNECTION = "connection"
    TABLE_OVERRIDE = "table_override"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.cron_schedule_spec import CronScheduleSpec


T = TypeVar("T", bound="AutoImportTablesSpec")


@_attrs_define
class AutoImportTablesSpec:
    """
    Attributes:
        schema_filter (Union[Unset, str]): Source schema name filter. Accepts filters in the form of *s, s* and *s* to
            restrict import to selected schemas.
        table_name_contains (Union[Unset, str]): Source table name filter. It is a table name or a text that must be
            present inside the table name.
        schedule (Union[Unset, CronScheduleSpec]):
    """

    schema_filter: Union[Unset, str] = UNSET
    table_name_contains: Union[Unset, str] = UNSET
    schedule: Union[Unset, "CronScheduleSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        schema_filter = self.schema_filter
        table_name_contains = self.table_name_contains
        schedule: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.schedule, Unset):
            schedule = self.schedule.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if schema_filter is not UNSET:
            field_dict["schema_filter"] = schema_filter
        if table_name_contains is not UNSET:
            field_dict["table_name_contains"] = table_name_contains
        if schedule is not UNSET:
            field_dict["schedule"] = schedule

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.cron_schedule_spec import CronScheduleSpec

        d = src_dict.copy()
        schema_filter = d.pop("schema_filter", UNSET)

        table_name_contains = d.pop("table_name_contains", UNSET)

        _schedule = d.pop("schedule", UNSET)
        schedule: Union[Unset, CronScheduleSpec]
        if isinstance(_schedule, Unset):
            schedule = UNSET
        else:
            schedule = CronScheduleSpec.from_dict(_schedule)

        auto_import_tables_spec = cls(
            schema_filter=schema_filter,
            table_name_contains=table_name_contains,
            schedule=schedule,
        )

        auto_import_tables_spec.additional_properties = d
        return auto_import_tables_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.cron_schedule_spec import CronScheduleSpec


T = TypeVar("T", bound="CronSchedulesSpec")


@_attrs_define
class CronSchedulesSpec:
    """
    Attributes:
        profiling (Union[Unset, CronScheduleSpec]):
        monitoring_daily (Union[Unset, CronScheduleSpec]):
        monitoring_monthly (Union[Unset, CronScheduleSpec]):
        partitioned_daily (Union[Unset, CronScheduleSpec]):
        partitioned_monthly (Union[Unset, CronScheduleSpec]):
    """

    profiling: Union[Unset, "CronScheduleSpec"] = UNSET
    monitoring_daily: Union[Unset, "CronScheduleSpec"] = UNSET
    monitoring_monthly: Union[Unset, "CronScheduleSpec"] = UNSET
    partitioned_daily: Union[Unset, "CronScheduleSpec"] = UNSET
    partitioned_monthly: Union[Unset, "CronScheduleSpec"] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        profiling: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.profiling, Unset):
            profiling = self.profiling.to_dict()

        monitoring_daily: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monitoring_daily, Unset):
            monitoring_daily = self.monitoring_daily.to_dict()

        monitoring_monthly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.monitoring_monthly, Unset):
            monitoring_monthly = self.monitoring_monthly.to_dict()

        partitioned_daily: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.partitioned_daily, Unset):
            partitioned_daily = self.partitioned_daily.to_dict()

        partitioned_monthly: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.partitioned_monthly, Unset):
            partitioned_monthly = self.partitioned_monthly.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if profiling is not UNSET:
            field_dict["profiling"] = profiling
        if monitoring_daily is not UNSET:
            field_dict["monitoring_daily"] = monitoring_daily
        if monitoring_monthly is not UNSET:
            field_dict["monitoring_monthly"] = monitoring_monthly
        if partitioned_daily is not UNSET:
            field_dict["partitioned_daily"] = partitioned_daily
        if partitioned_monthly is not UNSET:
            field_dict["partitioned_monthly"] = partitioned_monthly

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.cron_schedule_spec import CronScheduleSpec

        d = src_dict.copy()
        _profiling = d.pop("profiling", UNSET)
        profiling: Union[Unset, CronScheduleSpec]
        if isinstance(_profiling, Unset):
            profiling = UNSET
        else:
            profiling = CronScheduleSpec.from_dict(_profiling)

        _monitoring_daily = d.pop("monitoring_daily", UNSET)
        monitoring_daily: Union[Unset, CronScheduleSpec]
        if isinstance(_monitoring_daily, Unset):
            monitoring_daily = UNSET
        else:
            monitoring_daily = CronScheduleSpec.from_dict(_monitoring_daily)

        _monitoring_monthly = d.pop("monitoring_monthly", UNSET)
        monitoring_monthly: Union[Unset, CronScheduleSpec]
        if isinstance(_monitoring_monthly, Unset):
            monitoring_monthly = UNSET
        else:
            monitoring_monthly = CronScheduleSpec.from_dict(_monitoring_monthly)

        _partitioned_daily = d.pop("partitioned_daily", UNSET)
        partitioned_daily: Union[Unset, CronScheduleSpec]
        if isinstance(_partitioned_daily, Unset):
            partitioned_daily = UNSET
        else:
            partitioned_daily = CronScheduleSpec.from_dict(_partitioned_daily)

        _partitioned_monthly = d.pop("partitioned_monthly", UNSET)
        partitioned_monthly: Union[Unset, CronScheduleSpec]
        if isinstance(_partitioned_monthly, Unset):
            partitioned_monthly = UNSET
        else:
            partitioned_monthly = CronScheduleSpec.from_dict(_partitioned_monthly)

        cron_schedules_spec = cls(
            profiling=profiling,
            monitoring_daily=monitoring_daily,
            monitoring_monthly=monitoring_monthly,
            partitioned_daily=partitioned_daily,
            partitioned_monthly=partitioned_monthly,
        )

        cron_schedules_spec.additional_properties = d
        return cron_schedules_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
